#
# spec file for package blender
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2019-2021 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _dwz_low_mem_die_limit  40000000
%define _dwz_max_die_limit     200000000

%bcond_without alembic
%bcond_without collada
%ifarch x86_64
%bcond_without embree
%bcond_without oidn
%else
%bcond_with embree
%bcond_with oidn
%endif
%bcond_without opencl
%bcond_without opensubdiv
%bcond_without openvdb
%bcond_without osl
%bcond_with    system_audaspace

# TBD
%bcond_with usd
%bcond_with openxr

%if 0%{?suse_version} < 1550
%bcond_without python_36
%endif

%if 0%{?gcc_version} < 10
#global force_gcc_version 9
%bcond_without clang
%if 0%{?suse_version} >= 1550
%bcond_without lld
%else
%bcond_with    lld
%endif
%else
%bcond_with    clang
%endif

# Set this to 1 for fixing bugs.
%define debugbuild 0

# Find the version of python3 that blender is going to build against.
%define py3version %(pkg-config python3 --modversion)

# blender has versions like x.xxy which have x.xx (notice the missing
# trailing y) in the directory path. This makes this additional variable
# necessary.
%define _version %(echo %{version} | cut -b 1-4)
%define _suffix %(echo %{_version} | tr -d '.')

Name:           blender
Version:        2.92.0
Release:        1.4
Summary:        A 3D Modelling And Rendering Package
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/3D Editors
URL:            https://www.blender.org/
# Please leave the source url intact
Source0:        https://download.blender.org/source/%{name}-%{version}.tar.xz
Source1:        https://download.blender.org/source/%{name}-%{version}.tar.xz.md5sum
Source2:        geeko.blend
Source3:        geeko.README
Source4:        geeko_example_scene.blend
Source5:        geeko_example_scene.README
Source6:        %{name}-sample
Source8:        %{name}.appdata.xml
Source9:        SUSE-NVIDIA-GPU-rendering.txt
Source10:       SUSE-NVIDIA-OptiX-rendering.txt
Source99:       series
# PATCH-FIX-OPENSUSE Python 3.6 compatibility
Patch0:         make_python_3.6_compatible.patch
# PATCH-FIX-OPENSUSE https://developer.blender.org/D5858
Patch1:         reproducible.patch
#!BuildIgnore:  libGLwM1
BuildRequires:  OpenColorIO-devel
BuildRequires:  OpenEXR-devel
BuildRequires:  OpenImageIO
BuildRequires:  OpenImageIO-devel
BuildRequires:  SDL2-devel
BuildRequires:  clang-devel
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  distribution-release
BuildRequires:  fdupes
BuildRequires:  fftw3-devel
%if %{with clang}
BuildRequires:  clang
%if 0%{?sle_version} == 150200 && 0%{?is_opensuse}
BuildRequires:  libomp9-devel
%else
BuildRequires:  libomp-devel
%endif
%if %{with lld}
#!BuildIgnore:  gcc-c++
#!BuildIgnore:  binutils-gold
BuildRequires:  lld
%endif
%else
BuildRequires:  binutils-gold
BuildRequires:  gcc%{?force_gcc_version}-c++
%endif
BuildRequires:  gettext-tools
BuildRequires:  graphviz
BuildRequires:  help2man
BuildRequires:  hicolor-icon-theme
BuildRequires:  jack-audio-connection-kit-devel
BuildRequires:  libboost_atomic-devel
BuildRequires:  libboost_date_time-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_iostreams-devel
BuildRequires:  libboost_locale-devel
BuildRequires:  libboost_numpy3-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_python3-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libboost_serialization-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  libboost_wave-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libspnav-devel
BuildRequires:  libtiff-devel
BuildRequires:  llvm-devel
BuildRequires:  lzo-devel
BuildRequires:  openal-soft-devel
BuildRequires:  pcre-devel
BuildRequires:  perl-Text-Iconv
BuildRequires:  pkgconf-pkg-config
BuildRequires:  potrace-devel
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-requests
BuildRequires:  shared-mime-info
BuildRequires:  update-desktop-files
BuildRequires:  xz
BuildRequires:  xz-devel
BuildRequires:  cmake(pugixml)
BuildRequires:  pkgconfig(IlmBase)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(glw)
%if 0%{?suse_version} > 1500
BuildRequires:  pkgconfig(gmpxx)
%else
BuildRequires:  gmp-devel
%endif
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libxml-2.0)
%if %{with python_36}
BuildRequires:  pkgconfig(python3) >= 3.6
%else
BuildRequires:  pkgconfig(python3) >= 3.7
%endif
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xrender)
BuildRequires:  pkgconfig(xxf86vm)
BuildRequires:  pkgconfig(zlib)
# conditional requirements
%if 0%{?debugbuild} == 1
BuildRequires:  pkgconfig(valgrind)
%endif
%if 0%{?is_opensuse} == 1
BuildRequires:  pkgconfig(jemalloc)
%endif
%if %{with alembic}
BuildRequires:  alembic-devel
%endif
%if %{with collada}
BuildRequires:  openCOLLADA-devel
%endif
%if %{with embree}
BuildRequires:  embree-devel-static
%endif
%if %{with oidn}
BuildRequires:  OpenImageDenoise-devel
%endif
%if %{with opencl}
BuildRequires:  opencl-headers
%endif
%if %{with opensubdiv}
BuildRequires:  OpenSubdiv-devel
%endif
%if %{with openvdb}
BuildRequires:  openvdb-devel
BuildRequires:  tbb-devel
BuildRequires:  pkgconfig(blosc)
%endif
%if %{with osl}
BuildRequires:  OpenShadingLanguage-devel
%endif
%if %{with system_audaspace}
BuildRequires:  pkgconfig(audaspace) >= 1.3
Requires:       audaspace-plugins
%endif
%ifarch x86_64
Requires:       %{name}-cycles-devel = %{version}
%endif
Requires:       python3-base >= %{py3version}
Requires:       python3-numpy
Requires:       python3-requests
Requires:       python3-xml
Requires(post): hicolor-icon-theme
Requires(postun):hicolor-icon-theme
Provides:       %{name}-%{_suffix} = %{version}
# current locale handling doesn't create locale(..) provides correctly
Recommends:     %name-lang = %version
Recommends:     %name-demo = %version

%description
Blender is a 3D modelling and rendering package. It is the in-house
software of a high quality animation studio, Blender has proven to
be an extremely fast and versatile design instrument. The software
has a personal touch, offering a unique approach to the world of
Three Dimensions. Use Blender to create TV commercials, to make
technical visualizations, business graphics, to do some morphing,
or design user interfaces. You can easy build and manage complex
environments. The renderer is versatile and extremely fast. All
basic animation principles (curves & keys) are well implemented.It
includes tools for modeling, sculpting, texturing (painting,
node-based shader materials, or UV mapped), UV mapping, rigging and
constraints, weight painting, particle systems, simulation (fluids,
physics, and soft body dynamics and an external crowd simulator),
rendering, node-based compositing, and non linear video editing,
as well as an integrated game engine for real-time interactive 3D
and game creation and playback with cross-platform compatibility.

%ifarch x86_64
%package cycles-devel
Summary:        Headers for cycles rendering with %{name}-%{version}
#This package is for blender with cycles OSL
License:        Apache-2.0
Group:          Development/Sources
Requires:       %{name}-%{_suffix} = %{version}
BuildArch:      noarch

%description cycles-devel
These are the cycles headers that blender uses for rendering with
specific gpus
%endif

%package demo
Summary:        Some Blender demo files
License:        CC-BY-4.0
Group:          Productivity/Graphics/3D Editors
BuildArch:      noarch

%description demo
Some Blender demo scenes

geeko_example_scene: showing raytracing, rigging, animation, curves,
                     shading, texturing, vertex groups and rendering.

%lang_package

%prep
pushd "%{_sourcedir}"
md5sum -c %{SOURCE1}
popd

%setup -q
%if %{with python_36}
%patch0 -p1
%endif
%patch1 -p1

rm -rf extern/glew
rm -rf extern/libopenjpeg
# silence warning about missing includedir
mkdir -p extern/glew/include
for i in `grep -rl "/usr/bin/env python3"`;do sed -i '1s@^#!.*@#!/usr/bin/python3@' ${i} ;done

%build
export SUSE_ASNEEDED=0
%if %{with clang}
export CC="clang"
export CXX="clang++"
%define _lto_cflags -flto=full
%else
%if 0%{?force_gcc_version}
export CC="gcc-%{?force_gcc_version}"
export CXX="g++-%{?force_gcc_version}"
%endif
%endif

echo "optflags: " %{optflags}
# Find python3 version and abiflags
export psver=$(pkg-config python3 --modversion)
export pver=$(pkg-config python3 --modversion)$(python3-config --abiflags)
mkdir -p build && pushd build

# lean against build_files/cmake/config/blender_release.cmake
cmake ../ \
%if 0%{?debugbuild} == 1
      -DCMAKE_BUILD_TYPE:STRING=Debug \
      -DCMAKE_C_FLAGS_DEBUG:STRING="-fsanitize=address -ggdb" \
      -DCMAKE_CXX_FLAGS_DEBUG:STRING="-fsanitize=address -ggdb" \
      -DWITH_MEM_VALGRIND:BOOL=ON \
      -DWITH_ASSERT_ABORT:BOOL=ON \
%else
      -DCMAKE_C_FLAGS:STRING="$CFLAGS %{optflags} -fPIC -fopenmp" \
      -DCMAKE_CXX_FLAGS:STRING="$CXXFLAGS %{optflags} -fPIC -fopenmp" \
      -DWITH_MEM_VALGRIND:BOOL=OFF \
      -DWITH_ASSERT_ABORT:BOOL=OFF \
%endif
      -DCMAKE_CXX_STANDARD=17 \
      -DWITH_LLVM:BOOL=ON \
      -DLLVM_LIBRARY:FILE=%{_libdir}/libLLVM.so \
      -DCMAKE_VERBOSE_MAKEFILE=ON \
      -DCMAKE_INSTALL_PREFIX:PATH=%{_prefix} \
      -DCMAKE_EXE_LINKER_FLAGS:STRING="-pie" \
      -DBUILD_SHARED_LIBS:BOOL=OFF \
      -DWITH_INSTALL_PORTABLE:BOOL=OFF \
%if 0%{?is_opensuse} == 1
      -DWITH_MEM_JEMALLOC:BOOL=ON \
%endif
%if %{with alembic}
      -DWITH_ALEMBIC:BOOL=ON \
%endif
      -DWITH_BUILDINFO:BOOL=OFF \
      -DWITH_BULLET:BOOL=ON \
      -DWITH_CODEC_AVI:BOOL=ON \
      -DWITH_CODEC_FFMPEG:BOOL=ON \
      -DWITH_CODEC_SNDFILE:BOOL=ON \
      -DLIBSNDFILE_ROOT_DIR:FILE=%{_prefix} \
%ifarch ppc ppc64 ppc64le
      -DWITH_CYCLES:BOOL=OFF \
      -DWITH_CYCLES_EMBREE:BOOL=OFF \
%else
      -DWITH_CYCLES:BOOL=ON \
%if %{with osl}
      -DWITH_CYCLES_OSL:BOOL=ON \
      -DOSL_SHADER_HINT:PATH=%{_datadir}/OpenShadingLanguage \
%endif
%if %{with embree}
      -DWITH_CYCLES_EMBREE:BOOL=ON \
%else
      -DWITH_CYCLES_EMBREE:BOOL=OFF \
%endif
%endif
      -DWITH_DRACO:BOOL=ON \
      -DWITH_FFTW3:BOOL=ON \
      -DWITH_LIBMV:BOOL=ON \
      -DWITH_LIBMV_SCHUR_SPECIALIZATIONS:BOOL=ON \
      -DWITH_COMPOSITOR:BOOL=ON \
      -DWITH_FREESTYLE:BOOL=ON \
      -DWITH_IK_SOLVER:BOOL=ON \
      -DWITH_IK_ITASC:BOOL=ON \
      -DWITH_IMAGE_CINEON:BOOL=ON \
      -DWITH_IMAGE_DDS:BOOL=ON \
      -DWITH_IMAGE_HDR:BOOL=ON \
      -DWITH_IMAGE_OPENEXR:BOOL=ON \
      -DWITH_IMAGE_OPENJPEG:BOOL=ON \
      -DWITH_IMAGE_TIFF:BOOL=ON \
      -DWITH_INPUT_NDOF:BOOL=ON \
      -DWITH_INTERNATIONAL:BOOL=ON \
      -DWITH_LZMA:BOOL=ON \
      -DWITH_LZO:BOOL=ON \
      -DWITH_SYSTEM_LZO:BOOL=ON \
      -DWITH_MOD_REMESH:BOOL=ON \
      -DWITH_MOD_FLUID:BOOL=ON \
%ifnarch x86_64
      -DWITH_MOD_OCEANSIM:BOOL=OFF \
%else
      -DWITH_MOD_OCEANSIM:BOOL=ON \
%endif
      -DWITH_AUDASPACE:BOOL=ON \
%if %{with system_audaspace}
      -DWITH_SYSTEM_AUDASPACE:BOOL=ON \
%endif
      -DWITH_OPENAL:BOOL=ON \
%if %{with collada}
      -DWITH_OPENCOLLADA:BOOL=ON \
%else
      -DWITH_OPENCOLLADA:BOOL=OFF \
%endif
      -DWITH_OPENCOLORIO:BOOL=ON \
%if %{with oidn}
      -DWITH_OPENIMAGEDENOISE:BOOL=ON \
%endif
      -DWITH_OPENIMAGEIO:BOOL=ON \
      -DWITH_OPENMP:BOOL=ON \
%if %{with opensubdiv}
      -DWITH_OPENSUBDIV:BOOL=ON \
      -DOPENSUBDIV_OSDGPU_LIBRARY:FILE=%{_libdir}/libosdGPU.so \
%endif
%if %{with openvdb}
      -DWITH_OPENVDB:BOOL=ON \
      -DWITH_OPENVDB_BLOSC:BOOL=ON \
%endif
      -DWITH_PYTHON:BOOL=ON \
      -DWITH_PYTHON_INSTALL:BOOL=OFF \
      -DPYTHON_VERSION=$psver \
      -DPYTHON_LIBPATH=%{_libexecdir} \
      -DPYTHON_LIBRARY=python$pver \
      -DPYTHON_INCLUDE_DIRS=%{_includedir}/python$pver \
      -DWITH_PYTHON_INSTALL_NUMPY=OFF \
      -DPYTHON_NUMPY_PATH:PATH=%{python3_sitearch} \
      -DPYTHON_NUMPY_INCLUDE_DIRS:PATH=%{python3_sitearch}/numpy/core/include \
      -DWITH_QUADRIFLOW:BOOL=ON \
      -DWITH_SDL:BOOL=ON \
      -DWITH_TBB:BOOL=ON \
%if %{with usd}
      -DWITH_USD:BOOL=ON \
%endif
%if 0%{?is_opensuse} == 1
      -DWITH_MEM_JEMALLOC:BOOL=ON \
%endif
      -DWITH_JACK:BOOL=ON \
      -DWITH_SYSTEM_GLEW:BOOL=ON \
      -DWITH_DOC_MANPAGE:BOOL=ON \
      -DWITH_GHOST_XDND:BOOL=ON \
      -DWITH_X11_XINPUT:BOOL=ON \
      -DWITH_X11_XF86VMODE:BOOL=ON \
%if %{with openxr}
      -DWITH_XR_OPENXR:BOOL=ON \
%endif
%if %{with opencl}
      -DWITH_CYCLES_DEVICE_OPENCL:BOOL=ON \
%endif
      -DWITH_CYCLES_CUDA_BINARIES:BOOL=ON \
      -DWITH_CYCLES_CUBIN_COMPILER:BOOL=OFF \
      -DCYCLES_CUDA_BINARIES_ARCH="sm_30;sm_35;sm_37;sm_50;sm_52;sm_60;sm_61;sm_70;sm_75;compute_75" \
      -DWITH_CYCLES_DEVICE_OPTIX:BOOL=ON \
      -DOPTIX_ROOT_DIR:PATH=/opt/nvidia/optix

make %{?_smp_mflags}

%install
echo "release version = %{_version}"
# make install
%cmake_install

rm -f %{buildroot}%{_datadir}/%{name}/%{_version}/scripts/addons/.gitignore
# Fix any .py files with shebangs and wrong permissions.
find %{buildroot} -name "*.py" -perm 0644 -print0 | \
	xargs -0r grep -l '#!' | xargs -d'\n' chmod -f 0755;
# Copy text files to correct place.
mkdir -p %{buildroot}%{_docdir}/%{name}
mv -v %{buildroot}%{_datadir}/doc/blender/* %{buildroot}%{_docdir}/%{name}/
rmdir %{buildroot}%{_datadir}/doc/blender
# install blender sample.
install -D -m 0644 %{SOURCE2} %{buildroot}%{_docdir}/%{name}/
install -D -m 0644 %{SOURCE3} %{buildroot}%{_docdir}/%{name}/
install -D -m 0644 %{SOURCE4} %{buildroot}%{_docdir}/%{name}/
install -D -m 0644 %{SOURCE5} %{buildroot}%{_docdir}/%{name}/
install -D -m 0755 %{SOURCE6} %{buildroot}%{_bindir}/
# install appdata file
mkdir -p %{buildroot}%{_datadir}/appdata/
install -D -m 0644 %{SOURCE8} %{buildroot}%{_datadir}/appdata/
# GPU and OptiX rendering texts
install -D -m 0644 %{SOURCE9} %{buildroot}%{_docdir}/%{name}/
install -D -m 0644 %{SOURCE10} %{buildroot}%{_docdir}/%{name}/

chmod -f 0644 %{buildroot}%{_datadir}/%{name}/%{_version}/scripts/modules/console_python.py

%fdupes %{buildroot}%{_datadir}/%{name}/%{_version}/
%find_lang %{name} %{?no_lang_C}
rm -rf %{buildroot}%{_datadir}/locale/languages

%ifnarch x86_64
find %{buildroot}%{_datadir}/%{name}/%{_version}/scripts/ -name "*.h" -print -delete
%endif

# distinguishable menu entry
sed -i 's/^Name=Blender$/Name=Blender %{_version}/g' %{buildroot}%{_datadir}/applications/%{name}.desktop

# don't package thumbnailer
rm %{buildroot}%{_bindir}/%{name}-thumbnailer.py

%if 0%{?sles_version}
%suse_update_desktop_file -i -n %{name}
%else
# Validate blender.desktop
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}.desktop
%endif

%files lang -f %{name}.lang
%dir %{_datadir}/%{name}/%{_version}/datafiles/locale
%{_datadir}/%{name}/%{_version}/datafiles/locale/

%files
%{_bindir}/*
%{_mandir}/man1/%{name}.1.gz
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/%{_version}
%dir %{_datadir}/%{name}/%{_version}/datafiles
%exclude %{_datadir}/%{name}/%{_version}/datafiles/locale
%ifarch x86_64
%exclude %{_datadir}/%{name}/%{_version}/scripts/addons/cycles
%endif
%exclude %{_docdir}/%{name}/geeko_example_scene.*
%{_datadir}/%{name}/%{_version}/scripts/
%{_datadir}/%{name}/%{_version}/datafiles/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}*.svg
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{name}.appdata.xml
%doc %{_docdir}/%{name}

%ifarch x86_64
%files cycles-devel
%{_datadir}/%{name}/%{_version}/scripts/addons/cycles
%endif

%files demo
%doc %{_docdir}/%{name}/geeko_example_scene.*

%changelog
* Thu Mar 18 2021 Martin Liška <mliska@suse.cz>
- Enlarge dwz memory limits.
* Fri Feb 26 2021 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.92.0
  https://www.blender.org/download/releases/2-92/
- drop 0001-Dont-hide-required-uint64-atomic-ops-when-available.patch
  included in update
- pass the path for the numpy includes to cmake as the autodetect
  does not work right now.
* Tue Feb  9 2021 Hans-Peter Jansen <hpj@urpla.net>
- Exclude separately packaged demo files from main package
* Sat Feb  6 2021 Hans-Peter Jansen <hpj@urpla.net>
- Relocate new demo files into -demo package, and recommend it
- /usr/bin/blender-sample gained logic to deal with both geeko
  demos intelligently.
* Fri Jan 22 2021 Hans-Peter Jansen <hpj@urpla.net>
- Update to 2.91.2
  Checked items at: https://developer.blender.org/T83216
- Add geeko_example_scene.{blend,README} and load it from
  /usr/bin/blender-sample
* Sat Jan  9 2021 Hans-Peter Jansen <hpj@urpla.net>
- Require libomp9 devel dependency for Leap 15.2 explicitly
  in order to workaround a llvm setup issue
* Fri Jan  1 2021 Hans-Peter Jansen <hpj@urpla.net>
- Apply fix to make_python_3.6_compatible.patch provided by Mohamed
  Amazirh (fixes boo#1174816)
* Wed Dec  9 2020 Jason Craig <os-dev@jacraig.com>
- Fix grammatical error in SUSE-NVIDIA-GPU-rendering.txt
* Fri Nov 27 2020 Marcus Rueckert <mrueckert@suse.de>
- enable lto for the clang based build
- always build with SUSE_ASNEEDED=0
  building with clang and gcc fails during linking of bin/blender
- make it easier to force a new GCC version throughout the spec
  file: we just need one define now force_gcc_version and all parts
  of the spec file will follow
- bump memory size for LTO linking
* Fri Nov 27 2020 Hans-Peter Jansen <hpj@urpla.net>
- enable Cycles OPENCL support
* Thu Nov 26 2020 Marcus Rueckert <mrueckert@suse.de>
- use clang for systems with gcc older than 10. actually gets a
  working build. using clang on TW would require fixing the lto
  support first. clang complains about -flto=auto not supported.
* Thu Nov 26 2020 Marcus Rueckert <mrueckert@suse.de>
- drop unneeded %%post(un) scriptlets. they are handled via trigger
  now. fixes the warning about empty scriplets
* Thu Nov 26 2020 Marcus Rueckert <mrueckert@suse.de>
- disable system audaspace:
  the intree copy is patched now so the API no longer match
- disable SUSE_ASNEEDED for now as it leads undefined references
  while linking blender
- add potrace-devel to enable the tracing feature
- add gmpxx buildrequire to fix warning about missing library
- disable buildinfo option as it relies on git
- pass numpy path so it actually finds the includes
- refreshed patches:
  reproducible.patch
  make_python_3.6_compatible.patch
- update naming of the cuda/cubin options to the new schema
* Wed Nov 25 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.91.0
  https://www.blender.org/download/releases/2-91/
  https://wiki.blender.org/wiki/Reference/Release_Notes/2.91
* Tue Oct 13 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Explicitly disable embree on PPC*.
- Fix 32 bit architectures, add
  0001-Dont-hide-required-uint64-atomic-ops-when-available.patch
- Remove pointless physicalmemory _constraints already covered by
  memoryperjob constraint.
* Thu Sep 24 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.90.1
  - Decimate Modifier: Restore vertex group factor property in UI.
    rB97c6c4e47883
  - GPencil Opacity modifier not working. T80289
  - Extrude manifold can generate invalid geometry. T80233
  - Re-ordering face maps messes up the names of other face maps.
    T79973
  - Crash when deleting custom orientation. T80426
  - Crash after duplicating and hiding vertices while using X Axis.
    T80224
  - principle volume shader not working for world in Eevee. T80332
  - Eevee OpenVDB render error when frames miss part of the grids.
    T79718
  - PY API doc: fix doc for new override option of properties.
    rB09ef19996509
  - Crash when multi-mesh editing UVs with proportional editing.
    T80561
  - Crash adding properties to material node-trees. T80238
  - BLI_polyfill_calc exceeds stack size allocating points. T80604
  - Crash deleting bone constraints when the armature layer is.
    T80464
  - Cycles baking crash with locked-UI & background-mode. T71012
  - Hook modifier crashes without vertex group data. T80516
  - Mantaflow crash when adaptive domain + noise are enabled.
    T79626
  - Mantaflow Noise Not working with Smoke/Smoke and Fire. T80372
  - Vertex Colors not showing in edit mode. T78225
  - Correct Face Attributes affecting modes not listed. T80623
  - Edit Mode crash with shape keys created on blank mesh. T77584
  - Crash accessing depsgraph from evaluated view layer. T62504
  - Translations in python scripts are missing. T80589
  - Crash reloading scripts from the Python console. T80694
  - Library Override - Custom Property to Drive Child Particles
    results. T80457
  - Crash on undo/ redo after changing modes. T78392
  - UV edge select splits UV's for lasso/box/circle select. T80728
  - potential crash in volume grids in Eevee shaders. T80630
  - Fix OpenCL render error in large scenes. rB3dbb231ed2f8
  - Add versioning for 2.90 files that may have invalid mesh.
    rB3a92a2df4519
  - Texture paint camera project crashes after undo/redo. T80885
  - Auto IK Double Generates IK constraints. T80437
  - Cycles: Separate Embree device for each CPU Device.
    rB009971ba7adc
  - Cycles crash on macOS with older CPUs. T78793
  - Fix invert vertex group weight miscalculation for modifiers.
    rBe0f13f41c681
  - NLA Bake exception baking pose with non-pose selection. T61985
  - Tris to Quads ignores UV delimit option. T80520
  - Avoid changing the visibility of loose geometry. T80771
  - Archipack: support for bmesh bevel arguments changes in 2.90.
    rBA8e1b4dd71b37
  - Crash on editing multiple UVs of multiple different objects.
    T80899
* Mon Sep  7 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable explictly embree in cmake options. Fixes build on
  aarch64 and %%arm
* Thu Sep  3 2020 Hans-Peter Jansen <hpj@urpla.net>
- more spec cleanups
* Tue Sep  1 2020 Hans-Peter Jansen <hpj@urpla.net>
- Adjust spec to
  - require gcc9-c++ at least
  - align configuration with official builds
  - prepare for usd and openxr additions (TBD)
  - add support for NVIDIA compute_75 platform
  - prepare for NVIDIA OptiX support
- Add SUSE-NVIDIA-OptiX-rendering.txt
* Mon Aug 31 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.90.0
  https://www.blender.org/download/releases/2-90/
  https://wiki.blender.org/wiki/Reference/Release_Notes/2.90
- some features from the C++ stdlib require C++17. bump std version
  to it.
- refreshed make_python_3.6_compatible.patch
* Sat Aug 29 2020 Hans-Peter Jansen <hpj@urpla.net>
- openvdb >= 7.1.0 interface requires C++14 in order to build
  successfully.
* Sat Aug 22 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 2.83.5
  - FCurve editor crash when zooming out to limit [T79254]
  - Crash displaying the same mesh in two windows [T79260]
  - Fix interface artifacts on Intel GPUs [388639243053]
  - Outliner “Make Single User” crash [T79187]
  - Eevee cubemaps shows black [T79158]
  - Smooth brushes crasing in dyntopo [T79007]
  - Too much memory usage rendering animation with persistent
    images [T78537]
  - CLOG writes/reads outside allocated memory. [T78730]
  - Crash converting curve to mesh [T79207]
  - Fix usercount not decrementing in
    `gpencil_stroke_separate_exec` [4251a87bf60e]
  - UV select-linked failure to de-select [T46568]
  - GPencil weight paint crash when painting over modifier
    generated [T78884]
  - Workbench: Fix broken id pass [38e9a349defc]
  - Workbench: Object color mode broken if more than 4096 objects
    [T79509]
  - GPUShader: compile error on AWS Elastic Graphics [T79246]
  - Blend file corrupted during save caused by high Cubemap Size
    [T78529]
  - EEVEE: LightCache: Add warning if the cache cannot be saved
    [fce71a255cb9]
  - Crash loading nested set-scenes [T79575]
  - Fix crash switching render slots when there is only one slot
    [a9e0aeaf653d]
  - Triangulate quads with ‘Beauty’ can make zero area faces
    [T79482]
  - “Add plane > align” causes crash when certain rigs are in the
    scene [T77847]
  - Crash when changing View Layer while VR session runs [T79324]
  - Video Sequencer image sequence strip source path breaks
    [T79676]
  - Crash rendering grease pencil from compositor with multiple
    scenes [T77885]
  - EEVEE: Crash on Macos due to lightcache baking [T79703]
* Thu Aug 20 2020 Martin Liška <mliska@suse.cz>
- Use memoryperjob constraint instead of %%limit_build macro.
* Fri Aug  7 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 2.83.4
  - Crash when adjusting sequencer property [T78999]
  - GPencil: Fix unreported missing strokes in interpolation
    [dcf7a0507755]
  - Crash related to viewing video files [T78867]
  - Mantaflow Field weights cannot be animated [T79264]
  - Batch Generate-Previews doesn’t work anymore [T79031]
  - Dimensions fail on negative scaled axis [T79272]
  - Scale to Fit Text Box fails when text is too narrow [T77609]
  - Copy-pasting strip twice crashes Blender [T77669]
  - Prefetching can corrupt .blend files [T78837]
  - Random crash editing shader nodes with textures [T78358]
  - Missing depsgraph relation when using sound strips in VSE
    [T78920]
  - Fix View3D “Mirror” menu, both “Global” and “Local” items are
    GLOBAL [4a9d903e2bfd]
  - Crash displaying many aligned buttons [T78636]
  - Follow Active Quads, divide by zero error [T68845]
  - Crash when removing strips with prefetching [T78573]
  - Fresh install of blender 2.83.0 not able to save user startup
    file [T78037]
  - Weight Transfer Operator target mesh doesn’t update [T78306]
  - Weight Transfer Operator “Deform Pose Bones” destination
    setting [T78308]
  - Object disappears when scaled, set origin etc after applying
    smooth [T79180]
- remove 0001-Fix-T78867-Crash-related-to-viewing-video-files.patch
  as being fixed upstream
* Wed Aug  5 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add physicalmemory for PowerPC in _constraints to avoid OOM failure
* Thu Jul 30 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Increase %%limit_build value to avoid OOM failures
* Mon Jul 27 2020 Hans-Peter Jansen <hpj@urpla.net>
- After upgrading ffmpeg from 4.2.3 to 4.3.1, unaligned buffer
  accesses in yuv2rgb conversion result in segfaults:
  https://trac.ffmpeg.org/ticket/8747, https://trac.ffmpeg.org/ticket/8532
  Issue fixed for Blender with:
  https://developer.blender.org/rB6778ef4dcc6e8d92e3b2ec9b9ecaf1e54e5bf7b5
  0001-Fix-T78867-Crash-related-to-viewing-video-files.patch
* Fri Jul 24 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 2.83.3
  - Fix alignment/size issue on ARM/RPi architecture [9c41744ef4]
  - EEVEE: Cubemaps shows black [T75943]
  - Blender Freezes when using the 3d Scale Gizmo [T77455]
  - GPU: Apple/Nvidia Proxy check [T78175]
  - Fix missing GPU image free in background mode [9949b5098a]
  - Overlay: Weight colors are not in render in the right
    colorspace [T77780]
  - Cycles OpenCL error rendering empty scene [T77984]
  - Overlay: Edit mode + wire drawtype + infront not transparent
    [T77655]
  - Overlay: Sulpt overlay not working if object use in-front
    option [T76229]
  - Sculpt mode performance regression in 2.83 [T77641]
  - Faces missing, weird faces added [T74024]
  - Fix error when filtering in Outliner “Blender File” mode with
    libraries [d0c986b748]
  - Fix crash when use GPencil merge without materials [T78337]
  - Fix undefined behavior when using BSDF nodes inside volume
    shaders[T76171]
  - GPencil interpolation crash [T78134]
  - GPencil: Strokes go missing after Interpolation from another
    layer [T78042]
  - Workbench: “Not enough texture slots!” Message being spammed
    and lags the entire computer [T77759]
* Sat Jul 11 2020 Hans-Peter Jansen <hpj@urpla.net>
- Supply a Recommends: %%name-lang = %%version, because current locale
  handling doesn't create locale(blender:..) provides correctly
* Fri Jul 10 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.83.2
  - Random crash when rendering animation [T77734]
  - Overlay: “Outline Selected” overlay doesnt affect armatures
    [T66934]
  - Crash when closing window while Outliner shows screens
    [ef0ded4df389]
  - Crash on undo Draw Face Sets stroke with dyntopo active
    [T77328]
  - Fix random crash in Cycles smoke volume loading [2d89951be54d]
  - UV Editor: Fix Vertex Overlay color not being color managed
    [000fbef35d24]
  - Crash after any alembic import undo in an empty scene [T77754]
  - Crash on proxied rig, custom bone shape, driver targeting rig
    [T77712]
  - Crash in VR session when opening material preview [T77830]
  - Fix memory leak calculating deform modifiers in edit-mode
    [91b455c00f28]
  - Incorrect handling of negative-scale bit in DRWResourceHandle
    [T77913]
  - VSE Sequencer/Preview crash after fullscreen [T78112]
  - Compositor Disabled Node Config -> SegFault [T67358]
  - Undo crash due to IDTemplate operations missing undo push
    [T78172]
  - Simple scene created in version 2.82 crashes Blender [T77460]
* Wed Jul  8 2020 Hans-Peter Jansen <hpj@urpla.net>
- fix cycles dependency
* Tue Jul  7 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.83.1
  - Fix T77774: New undo code broken by ‘make local’ behavior
  - Audio SDL: Video editor Sound muted without muting it
  - Fix T77803: IK Degrees of freedom drawing glitch
  - Fix (unreported) wrong size of UserPreferences’ `dupflag`
    parameter. Fix Applied rBdceaef92d7a4: Fix (unreported) wrong
    size of UserPreferences’ `dupflag` parameter
  - Fix T77915: Cycles OSL microfacet closure not working in custom
    shaders
  - GPencil: Fix unreported Vertex Opacity Overlay not working
  - Fix T75414: Incorrect masking in Color Balance modifier
  - Fix T76767: Cycles performance regression with CLI renders
  - Fix T77853: Error reloading linked library
  - Fix missing hinting information in monospace font,
    rB783d3c675ac2: Fix missing hinting information in default font
  - Fix T77657: NVIDIA Quadro FX4800 crash on startup
  - GPencil: Improve viewlayer masking check
  - Fix T77148: Crash changing multiple values for sequencer strips
  - Fix T77047: Dyntopo Sample detail size on hidden mesh causes
    crash
  - Fix T74101: File Browser in macOS fullscreen crashes or makes
    windows unusable
  - Fix T77504: Operator search gives wrong results
  - Fix T76894: Disable clipping region selection in
    material/rendered mode
  - Fix T72936: Incorrect gizmo orientation with inherit rotation
    disabled
  - Fix menu operator/search clipping the last character Fix
    Applied rBf649e5c418d9: Fix menu operator/search clipping the
    last character
  - Fix T77603: OSL parser fails when script ends with comment
    without newline
  - Fix crash running “Edit Voxel Size” operator outside of a main
    3D View region Fix Applied rB5fc252feaeab: Fix crash running
    “Edit Voxel Size” operator outside of a main 3D View region
  - GPencil: Fix unreported error in Dots Strokes material
    initialization
  - GPencil: Fix unreported Shift+F OPacity key not working
  - Calculate epsilon values for interp_weights_poly to improve
    accuracy Fix Applied rB9d5e5e282cff: Calculate epsilon values
    for interp_weights_poly to improve accuracy
  - Fix T76273 Glitches caused by glCopyImageSubData on windows +
    intel gpu Fix Applied rB7b754c8c9952: Fix T76273 Glitches
    caused by glCopyImageSubData on windows + intel gpu
  - Fix T77358: Gpencil can’t select geometry within transparent
    layers
  - Fix T77520: GPencil viewlayer filter produce crash with masking
    layers
  - Fix T77367: Blender’s snap package ignores command line options
  - Fix for T77095: work around render artifacts with AMD Radeon RX
    4xx and 5xx
  - Fix T77164: scaling/rotation fails for 3 selected NURB points
  - Fix T77156: GPencil view layer filter by layer not working
  - Fix T77456: Broken vertex paint undo on high-poly objects
  - Fix T77448: Camera Solver constraint can’t be converted to
    f-curve
- changes from version 2.83.0
  https://wiki.blender.org/wiki/Reference/Release_Notes/2.83
- do not delete the fonts directory:
  it is actually needed for blender and we already packaged the
  license file
- drop blender-add-OSL-1_11-compat.patch: included in update
- refreshed patch to apply cleanly again:
  make_python_3.6_compatible.patch
* Thu May 14 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Readjust _constraints, x86_64 had the lowest constraint, but the
  most enabled features. The constraint was raised twice due to
  merging changes. 4G for anything but x86_64 is sufficient.
* Tue May 12 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Replace blender-bad-override.patch with upstream change,
  blender-add-OSL-1_11-compat.patch. The previous patch was just
  wrong, removing an override specifier just silences the compiler,
  ignoring the error it is meant to catch.
* Fri Apr 24 2020 Dave Plater <davejplater@gmail.com>
- Add blender-bad-override.patch to fix build with
  OpenShadingLanguage >= 2.0.0
* Fri Apr  3 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to sort file lists
  to make package build reproducible (boo#1041090)
* Fri Mar 13 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 2.82a:
  * Move 2.82a from beta to release
  * Fix shader build error
  * Fix T74425: Cannot texture paint an images sequence anymore
  * Fix T73369: corner pin & sun-beam nodes gizmos are too big
  * Fix T63892: Tools cannot be registered into some contexts (e.g. PAINT_TEXTURE)
  * Fix T74225: Image (from sequence) cannot be loaded
  * Fix Vertex weight gradient tool show wrong weight/strength values in the UI
  * Fix bone envelopes displaying wrong when armature is scaled
  * Fix T72028: Crash switching to vertex paint
  * Keymap: Add front/back Alt-MMB absolute view axis switching
- Use git scm service to fetch the source
* Sat Feb 29 2020 Hans-Peter Jansen <hpj@urpla.net>
- remove lang recommends
- provide/obsolete blender-282-devel
* Sun Feb 23 2020 Hans-Peter Jansen <hpj@urpla.net>
- Add SUSE-NVIDIA-GPU-rendering.txt
* Wed Feb 19 2020 Hans-Peter Jansen <hpj@urpla.net>
- improve cuda configuration
* Tue Feb 18 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.82:
  https://wiki.blender.org/wiki/Reference/Release_Notes/2.82
- dropped patches:
  0001-Fix-T71680-_PyObject_LookupAttr-memory-leak.patch
  0006-add_ppc64el-s390x_support.patch
- refreshed patches:
  - make_python_3.6_compatible.patch
    dropped the memory leak fix from the patch
- track series file in spec file to make quilt easier
- enable _smp_mflags. seems to work with 2.82
- drop unused options from the spec file:
  WITH_RAYOPTIMIZATION
  WITH_MOD_SMOKE
* Wed Feb  5 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 2.81a:
  bugfix release, check:
  https://wiki.blender.org/wiki/Reference/Release_Notes/2.81/a
* Sun Jan 12 2020 Hans-Peter Jansen <hpj@urpla.net>
- Recommends lang package
- Add Provides to deal with suffixed blender packages (blender-xxx)
  gracefully
* Tue Nov 26 2019 Hans-Peter Jansen <hpj@urpla.net>
- Add patch 0001-Fix-T71680-_PyObject_LookupAttr-memory-leak.patch
  Stefan's Python 3.6 compatibility patch revealed a memory leak,
  that is plugged upstream in master already. Fix either with
  applying this patch or make_python_3.6_compatible.patch.
* Tue Nov 26 2019 Hans-Peter Jansen <hpj@urpla.net>
- Enable OIDN again
* Mon Nov 25 2019 Hans-Peter Jansen <hpj@urpla.net>
- Disable OIDN for all builds, until accepted in Factory
* Thu Nov 21 2019 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 2.81:
  * way* too many changes to list here, for an overview, check:
  https://wiki.blender.org/wiki/Reference/Release_Notes/2.81
- Add OpenImageDenoise support
- Sync build options with blender_release.cmake
- Remove SSE compile options, they are enabled for x86_64 by default
- Rebase both patches:
  * 0006-add_ppc64el-s390x_support.patch
  * make_python_3.6_compatible.patch
- delete make_python_3.6_compatible.diff by renaming.
* Wed Nov 20 2019 Hans-Peter Jansen <hpj@urpla.net>
- use build conditionals for python_36 selection
- remove superflous WITH_SYSTEM_OPENJPEG build flag
* Tue Nov 19 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Replace two uses of _PyObject_LookupAttr (Python 3.7 C API) with
  equivalent calls from Python 3.6, Python 3.6 is sufficient now.
  * Add make_python_3.6_compatible.diff
- Replace cmake(TBB) BuildRequires with equivalent tbb-devel, the
  latter is also available on Leap 15.x.
- Correct URL and Source, http causes a permanent redirect.
* Fri Nov  8 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use upstream default for JACK_DYNLOAD (i.e. off), this is a
  feature for portable builds (see https://developer.blender.org/D878),
  Jack is already pulled in via libav*.
* Thu Nov  7 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Set proper memory constraints. About 5.5G are required on
  x86_64, which has more features like embree (and builds on
  e.g. build32/build33 with 2.2+2G recurrently failed).
- Remove LTO mangling, it did not reduce the memory required for
  linking, and disabling LTO altogether dependent on available
  memory makes the build unreproducible.
* Thu Nov  7 2019 Hans-Peter Jansen <hpj@urpla.net>
- raise memory constraints (phys: 2 -> 4 GB, total: 4 -> 8 GB)
* Mon Nov  4 2019 Hans-Peter Jansen <hpj@urpla.net>
- distinguishable menu entry
* Tue Oct 15 2019 Hans-Peter Jansen <hpj@urpla.net>
- Don't remove 0-length files
  would mostly remove __init__.py files, which is harmful
- Remove wplayer build conditional (option not available anymore)
* Wed Oct  2 2019 Dave Plater <davejplater@gmail.com>
- Fix ppc build with 0006-add_ppc64el-s390x_support.patch.
* Sun Sep 29 2019 Dave Plater <davejplater@gmail.com>
- If $_threads are less than 4 undefine _lto_cflags as the value of
  3 or less fails at link time also build with one thread.
* Wed Sep 25 2019 Dave Plater <davejplater@gmail.com>
- Ensure that _lto_cflags are defined as nil if multi threaded make
  fails.
* Sun Sep 22 2019 Dave Plater <davejplater@gmail.com>
- Worked around %%limit_build macro's failure to provide -flto= with
  the correct value.
* Fri Sep 20 2019 Hans-Peter Jansen <hpj@urpla.net>
- Enable OpenSubdiv, openvdb, alembic.
- Enable embree for x86_64.
- Order dependencies properly, build conditionals rearward
* Sat Aug 31 2019 Dave Plater <davejplater@gmail.com>
- Disable OpenSubdiv, openvdb and alembic until they are accepted
  to Factory
* Fri Aug 23 2019 Hans-Peter Jansen <hpj@urpla.net>
- Enable OpenSubdiv, openvdb and alembic
* Fri Aug  2 2019 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 2.80
  * way* too many changes to list here, for an overview, check:
  https://wiki.blender.org/wiki/Reference/Release_Notes/2.80
- specify CYCLES_CUDA_BINARIES_ARCH
- adhere more closely to upstream release build options
- add missing boost libs
- use openjpeg2
- use sndfile
- enable openmp suppprt
- define the supported cuda binary archs
- clean up spec
- remove patches, fixed upstream
  - 0001-Added-extra-const-to-satisfy-the-strict-clang-versio.patch
  - 0001-Cycles-Fix-bad-register-cast-in-sseb.patch
  - 0001-Fix-PyRNA-class-registration-w-Python-3.7.patch
  - 0008-fix_building_with_latest_versions_of_FFmpeg.patch
  - 0001-Fix-for-GCC9-new-OpenMP-data-sharing.patch
* Thu Jul 25 2019 Dave Plater <davejplater@gmail.com>
- Move the limit_build macro to the top of the build section to
  limit lto processes to the number of threads.
* Sat Jul 13 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix building with GCC9, add
  0001-Fix-for-GCC9-new-OpenMP-data-sharing.patch
- Switch back to GCC, to fix issues with LTO now enabled in Tumbleweed
* Thu May 30 2019 Hans-Peter Jansen <hpj@urpla.net>
- switch compiler to clang
* Fri Mar 22 2019 plater <davejplater@gmail.com>
- Enabled spacenav input, requested by Lo Matrix.
- Build all of blender in one %%limit_build makes this possible.
* Thu Mar 21 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Properly fix Boost dependencies, Boost 1.69 no longer pulls in
  libboost_system-devel. If it is missing, the configure logic
  silently omits boost_locale from the link libraries.
- Reduce build time by replacing the open coded job limit with
  the limit_build macro.
* Tue Mar 19 2019 plater <davejplater@gmail.com>
- Fix build with new boost by adding linker flag -lboost_locale.
- This fixes boo#1129626
- Refreshed patches
* Thu Feb 14 2019 bjorn.lie@gmail.com
- Add 0008-fix_building_with_latest_versions_of_FFmpeg.patch: Fix
  build with current ffmpeg v4.
- Following the above patch, no longer force ffmpeg-3 versions of
  pkgconfig(libav*).
* Tue Feb 12 2019 davejplater@gmail.com
- Fix boo#1124964 with patch from blender git:
  0001-Fix-PyRNA-class-registration-w-Python-3.7.patch
* Mon Jan 28 2019 Jan Engelhardt <jengelh@inai.de>
- Properly accessing the RPM source directory makes
  quilt work again.
* Thu Jan 10 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Cleanup spec file
  * Replace gtk-update-icon-cache with icon_theme_cache_post{,un} macros
  * Use bcond_with/bcond_without
  * Drop obsolete blender-2.78-C++11-build-fix.patch
  * Remove BuildRequires for some unused boost-devel subpackages
- Allow latest LLVM package, instead of forcing LLVM5
* Tue Jan  1 2019 davejplater@gmail.com
- Enabled build with Open Shading Language using initial
  OpenShadingLanguage version 1.9.13. See boo#1120406
- Renamed blender-devel to blender-cycles-devel which better
  reflects the sub packages use and also ensures that the OSL
  headers are installed with OSL enabled blender.
* Tue Aug 28 2018 jengelh@inai.de
- Put back %%_smp_mflags ahead of %%_jobs so that "-l" arguments
  from smp_mflags are preserved.
- Remove silly "break" inside "if..then"
- Use xargs right
* Sun Aug 26 2018 stefan.bruens@rwth-aachen.de
- Replace macro for limiting parallel builds with a working one.
- Increase memory constraints to 2GB physical/4GB total. This is
  the typical minimum available anyway.
- Increase limit for parallel builds from 2 to 4.
* Sun Aug 26 2018 stefan.bruens@rwth-aachen.de
- Remove x-blend.desktop, it does not do what it claims (opening
  templates), and duplicates the existing one (bnc#1102918).
- Remove xpm file and any icons in /usr/share/pixmaps/. The latter
  has been deprecated in favor of the themable /usr/share/icons/
  for a long time.
* Fri Jun 22 2018 wbauer@tmo.at
- Add upstream patches to fix build with gcc8:
  * 0001-Added-extra-const-to-satisfy-the-strict-clang-versio.patch
  * 0001-Cycles-Fix-bad-register-cast-in-sseb.patch
* Tue Jun  5 2018 davejplater@gmail.com
- Only allow headers for x86_64 arch.
* Sat Jun  2 2018 davejplater@gmail.com
- Only allow headers for x86_64 arch.
* Fri Jun  1 2018 davejplater@gmail.com
- Package blender cycles headers in blender-devel sub package to
  fix boo#1094777.
- Remove Compatibility_Warning.txt.
* Tue Mar 27 2018 davejplater@gmail.com
- Update to release 2.79b.
- Upstream changes:
  This is a bug fix release.
* Tue Mar 27 2018 crrodriguez@opensuse.org
- Remove xorg-x11-devel from buildrequires.
- Reorder/rework buildrequires, packages libao-devel,
  libdrm-devel, libexpat-devel,libvorbis-devel,openssl-devel,
  libsamplerate-devel are not required and were removed.
- Build using -DWITH_SYSTEM_LZO so lzo-devel is actually
  used.
* Fri Mar  2 2018 davejplater@gmail.com
- Update to release 2.79a
- Upstream changes:
  Blender 2.79a features a new Denoiser, PBR Shader, Shadow Catcher,
  Filmic Color Management, AMD OpenCL improvements and much more.
  All of that plus over a massive 900 bug fixes!
* Tue Oct  3 2017 dimstar@opensuse.org
- Do not BuildRequire openSUSE-release: in TW, this is a daily
  changing package, invalidating blender daily. There is no
  information a package would require, which is not also available
  in distribution-release (which exists for this very purpose and
  can be used across SUSE distributions, incl. Leap/SLE).
* Wed Sep 20 2017 davejplater@gmail.com
- Update to release 2.79
- Remove blender-system-audaspace.patch incorporated in this version
- Now build with ffmpeg and cyles unconditionaly.
- Added blender-2.78-C++11-build-fix.patch for future openvdb build.
- Specifically require audaspace-plugins to fix boo#1057965.
- Add Compatibility_Warning.txt to warn about 2.78/2.79 compatibility
  problems on installation.
- Upstream changes:
  * Cycles: Built-in Denoising, Shadow catcher,Principled shader,
    AMD OpenCL optimizations.
  * Grease Pencil: New frame interpolation tools, per-layer onion
    skinning.
  * Alembic: Improvements to compatibility, stability and support.
  * User Interface: Initial support for reusable custom
    configurations, automatic DPI scaling.
  * Twenty Three new and several updated add-ons.
  * 100s of bug fixes and other improvements!
  * Compatibility Warning
    Due to various issues with drivers for AMD GCN 1.0 architecture
    , those cards are no longer supported for Cycles rendering
    When using add-ons in Blender 2.79 that take advantage of the
    new data-block pointer properties, the resulting .blend files
    can't be opened in earlier versions of Blender. Attempting to
    open such .blend files in Blender 2.78c and earlier may crash.
    Some Interface Themes may need to be reloaded to work properly.
    The text color contained in a layout.box() is now defined in
    User Preferences » Themes » User Interface » Box section
    Rig compatibility:
    Changes to IK snapping may affect rigs that use non-uniform
    IK scaling. (rigs created in the 2.78 builds.)
    During the 2.78 series: IK snapping was partly broken.
    This has been fixed for Blender 2.79
    Rigs created in Blender 2.78 may not be compatible with
    2.79.
    Rigs created in Blender 2.77 may still work.
    When using the add-on Rigify, please note:
    Compatibility is broken for this release. There's no
    guarantee rigs created in previous Blender versions will
    work correctly.
    Rigs created in Blender 2.78 may not be compatible with 2.79.
    Rigs created in Blender 2.77 may still work.
    Save your work before attempting upgrading your rigs.
- See:https://wiki.blender.org/index.php/Dev:Ref/Release_Notes/2.79
  For a comprehensive list.
* Thu May 18 2017 ideasman42@gmail.com
- Remove doxygen (only documents internal source code, not
  public / scripting API's).
* Thu May 18 2017 ideasman42@gmail.com
- Remove yasm (was only needed for extern/ codecs) now removed.
- Remove ruby (Blender doesn't use Ruby).
* Wed May 17 2017 ideasman42@gmail.com
- Remove extern paths which no longer exist, also epydoc which
  isn't used since 2.4x.
* Fri Apr  7 2017 davejplater@gmail.com
- Enabled system audaspace with blender-system-audaspace.patch
  which fixes the crash. see boo#1027923 and github audaspace #7
* Sun Mar  5 2017 davejplater@gmail.com
- Disabled system audaspace due to email crash report.
* Wed Mar  1 2017 davejplater@gmail.com
- Update to 2.78c
- Upstream changes:
  Port all changes for automated Cycles testing.
  Fix for wrong render result of hair with BVH motion steps.
  Fix compilation error of GLSL viewport when using Light Path node.
  Fix wrong Brick texture in material viewport.
  Fix crash with material preview and image sequences.
  Fix T50512: Linked Backround scene with animation not updating
  with new depsgraph.
  Fix T50687: Cycles baking time estimate and progress bar doesn't
  work / progress when baking with high samples.
  Fix T50748: Render Time incorrect when refreshing rendered preview
  in GPU mode.
  Fix wrong render results with texture limit and half-float
  textures.
  Fix Cycles still saving render output when error happened.
* Fri Feb 10 2017 davejplater@gmail.com
- Build with system audaspace.
* Fri Feb 10 2017 davejplater@gmail.com
- Update to version 2.78b
- Bugfix version
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sun Nov 13 2016 davejplater@gmail.com
- Use %%mime_database_post macro instead of calling direct.
* Wed Nov  2 2016 davejplater@gmail.com
- Update to version 2.78a.
- Upstream changes:
  * For 2.78a, 69 bugs were fixed,the two outstanding points being:
  * Cycles is now using Cuda8 for all GPUs, performances issues with
  “old” ones have been fixed.
  * Several issues were fixed in new data-blocks management code,
  including some crashers, and bad “append” behaviors.
  * Fix T49629: Graph editor normalize function doesn't work on
  f-curves with a constant key value (rB8ebc7565e7).
  * Fix T49571: 2d stabilize keys not visible in the Graph Editor
  and Dope Sheet (rBd1f5c0fe48).
  * Fix T49622: Grease pencil not rendering out of VSE
  (rB9d4e3b0e63).
  * Fix unreported: Fix: Grease Pencil palettes were missing a RNA
  path callback (rB0b734f0b59).
  * Fix unreported: Fix export image generated by export UV layout
  (rB3bf9cbe7a2).
  * Fix T49471: Vertex Connect randomly broken (rB949b23d29b).
  * Fix T49478: triangulate of face hangs Blender (rB08e4846540).
  * Fix unreported: Fix assert in the wrong place, should be moved
  earlier to do anything (rB8030c4832a).
  * Fix T49464: Data Transfer modifier slows down redraw of window
  (rBff27b58b4c).
  * Fix T49595: bpy - negative skin_vertices radius crashes Blender
  (rB02eec191fb).
  * Fix unreported: Normal edit modifier: Fix relation builder for
  the new dependency graph (rB106ff0df99).
  * Fix T49548: Entering Cycles Rendered Viewport Unlinks Material
  from Objects (rB4640bf890e).
  * Fix T49827: L Crash linking material while in Material viewport
  shading mode (rB452d43b1c8).
  * Fix unreported: Fix mistake in BKE_mesh_new_from_object handling
  of materials in MetaBall case (rB602b2dbd8c).
  * Fix T49460: Particle group instance 'Use Count' value gets reset
  on file-load (rB8aa04160ba).
  * Fix T49608: runtime-only particle's boid->ground Object pointer
  was left dangling to invalid value in read code (rB29fdcbbf9f).
  * Fix T49738: Hair Add Brush doesn't work (rB50751d62e9).
  * Fix unreported: Ammend torB00dc0666b3fe: forgot to fix
  boid->ground of first particle (rB7ab972fd63).
  * Fix T49461: Dynamic paint wetmap flickers (rBa88af3e576).
  * Fix T49636: material draw mode crash with displacement and
  missing group input node (rBc9b5253cfc).
  * Fix T49789: Compositor mix node interpolation bug
  (rBe1cf002ee6).
  * Fix T49523: very slow normal map tangent computation for
  rendering in 2.78 (rB0d1bc587fa).
  * Fix T49609: Point density textures: vertex colors are not
  properly averaged in BI (rB880ebfff58).
  * Fix T49623: Immediately crash trying to render attached file in
  Cycles (rBbe254b52dc).
  * Fix T49640: Cycles constant folding incorrect for texture
  coordinates (rB10598c084e).
  * Fix T49750: Cycles wrong ray differentials for perspective and
  stereo cameras (rB4c94e327a2).
  * Fix T49818: Crash when rendering with motion blur
  (rB66ed7d7566).
  * Fix unreported: Cycles: Fix typo in shader cancel routines
  (rB08d21ff582).
  * Fix unreported: Fix wrong Cycles GLSL pointiness, still not
  supported but should be neutral 0.5 (rB4da266f48c).
  * Fix unreported: Fix Cycles CUDA performance on CUDA 8.0
  (rBfd0dea585c).
  * Fix unreported: Cycles: Fix OpenCL split kernel compilation
  after recent CUDA 8 performance fix (rB117329ae6d).
  * Fix unreported: Cycles: Fix use of uninitialized variable in SSS
  (rBb42e4c3c40).
  * Fix unreported: Cycles: Fix uninitialized variable from the
  previous commit (rBf55221e0a1).
  * Fix unreported: Cycles: Fix static initialization order fiasco
  (rBf0adb875cf).
  * Fix unreported: Fix Cycles address space OpenCL error after
  recent fix (rB759b5fb2a6).
  * Fix unreported: Cycles: Fix shadowing variable which also causes
  use of uninitialized variable (rB21bf863934).
  * Fix unreported: Fix missing outliner redraw when adding VSE
  strip (rB00d08c909d).
  * Fix T49534: 2.78 Wrong texture scaling in material viewport
  (rB3fb0c1b8e7).
  * Fix unreported: Fix missing properties editor update when
  changing 3D View camera (rB483b4f0567).
  * Fix unreported: UPBGE: Fix crash when calling shade_light
  texture when mtex has no tex (rBf978deddf8).
  * Fix unreported: Fix viewport camera gets out of sync in certain
  cases (rBcdedd082f3).
  * Fix T49506: Remove unused File Browser theme settings
  (rB11120c2981).
  * Fix T49631: radial control operators not using DPI properly
  (rB97bba76e8c).
  * Fix T49635: column_flow Layout - last column is too small
  (rB03f935961a).
  * Fix T49646: Switching from large to small image can get stuck
  zoom at max zoom distance (rBe6d9b15ab3).
  * Fix T49601: Material menu length problem (rBdacb53ff71).
  * Fix T49746: crash loading user preferences with missing
  operators (rBa6220f459b).
  * Fix unreported: Fix missing new eyedropper keymap entry in
  keyconfig_utils.py (rB07508c8b93).
  * Fix unreported: Fix memory leak caused by unknown opeartor of
  keymap item (rB4d14bd10c0).
  * Fix unreported: Fix wrong separator line width after drawing vec
  icon (rB2525c4e129).
  * Fix T49520: broken vertex colors in the game engine
  (rBe96e66b05b).
  * Fix T49764: Audio strips crackle when animating the volume
  (rB1bcddea00e).
  * Fix T49656: Crash when starting playback while using JACK audio
  with A/V sync (rB7b311c07ee).
  * Fix T49423: Data Preview of group containing only group
  instances is empty (rBa05f9bef3f).
  * Fix T49502: file browser on OS X not highlighting system folders
  and bookmarks (rB9fea90ba36).
  * Fix T49501: Animations imported via alembic render with wrong or
  no motion blur (rBe65e5045de).
  * Fix T49502: file browser on OS X not highlighting external
  drives (rB4736664da6).
  * Fix unreported: Fix missing operator-type registration
  (rBe145990fdd).
  * Fix T49466: Stupid typo in logicbricks new copy code
  fromrB776a8548f03a (rBd78a4b0c62).
  * Fix T49489: Pose marker in camera action + marker bound to
  camera -> crash (rB7b43307508).
  * Fix T49553: Blender 2.78 crashes when File->Data Previews
  - >Refresh Datablock Previews (rBb8194a52a0).
  * Fix T49722: Appending Bug (Groups) (rB44372d6441).
  * Fix T49775: Appending data with internal dependency cycles
  prevents correct clearing of linked data-blocks (rB3da4560143).
  * Fix unreported: Fix Scene datablocks being created with a real
  user while never having any real datablock user (rBcb9d010421).
  * Fix unreported: Fix OLD pre-git links in the API, add missing
  factory-startup option to blender executions (rBfd9aa06440).
  * Fix T49797: Exception from scene update handler might leak
  external engine descriptors (rBdac53963a8).
  * Fix unreported: BLI_task: fix case were some pool could work in
  more threads than allowed (rB4dbcbf5ba9).
  * Fix unreported: Fix a few compile errors with C++11 on macOS
  (rBcb6c43b61c).
* Sun Oct  2 2016 davejplater@gmail.com
- Update to release 2.78
- Removed blender-2.58-python_include.patch, no longer relevant.
- Upstream changes:
  The Blender Foundation and online developer community are proud
  to present Blender 2.78, released September 30th 2016!
  This release aims to be a very stable one, so that developers
  can focus better on Blender 2.8 work. Some of the highlights:
    Spherical Stereo images rendering support for VR
    Grease Pencil is now a full 2D drawing & animation tool!
    Viewport Rendering improvements
    New Freehand curves drawing over surfaces!
    Bendy Bones, powerful new options for B-Bones
    Alembic support: import/export basic operators
    Cloth Physics: new Dynamic Base Mesh and Simulation Speed
    option
    New Add-ons, individual preferences, Python APIs changes, and a
    lot of new & updated add-ons!
    For more details see:
    https://www.blender.org/features/2-78/
  Bugfixes, too many for this changelog, see:
  https://wiki.blender.org/index.php/Dev:Ref/Release_Notes/2.78/Bug_Fixes
* Wed Aug 10 2016 badshah400@gmail.com
- Add blender.appdata.xml as a source file and install it to
  %%{_datadir}/appdata/. This makes blender show up in appstores
  like GNOME Software and KDE Discover, making it more easily
  discoverable and installable.
* Mon Jun 20 2016 davejplater@gmail.com
- Ensure that package is uninstallable in systems with a lower
  python3 version than blender was built against.
* Fri Jun 17 2016 adrian@suse.de
- use sse compiler options only on supported architectures
- fix build on ppc by skipping colormanagement
- drop SUPPORT_SSE2_BUILD since it is not used by cmake anymore
* Mon Jun  6 2016 davejplater@gmail.com
- Moved %%{_datadir}/%%{name}/%%{_version}/datafiles/ back to main
  package after it somehow ended up in the language package. See
  boo#983064.
- Added build requirements to bring package in line with the
  official blender build.
* Thu Apr 21 2016 davejplater@gmail.com
- Added debugbuild macro to the spec file to enable debugging.
  See boo#976293.
* Sat Apr 16 2016 olaf@aepfle.de
- Use pkgconfig instead of libffmpeg-devel
* Wed Apr 13 2016 davejplater@gmail.com
- Update to release 2.77a
- Removed patch blender-2.77-bufferoverflow.patch upstream fixed.
- Upstream changes:
  For 2.77a many fixes for OpenGL display and simulation were made,
  as well as various fixes to rendering, sequencer and modeling.
  This bugfix release also solved some regressions in the particle
  system.
* Wed Mar 23 2016 davejplater@gmail.com
- Update to version 2.77
- Upstream changes:
  Cycles: Better Subsurface Scattering, GPU support for Smoke/Fire
    and Point Density.
  Grease pencil stroke sculpting and improved workflow.
  OpenVDB caching for smoke/volumetric simulations.
  Reworked library handling to manage missing and deleted
    datablocks.
  Redesigned progress bar.
  Edit mode boolean tool, better decimate modifier.
  Improved extruding and weight painting tools for
    sculpting/painting.
  And: 100s of bug fixes and other improvements!
- Added blender-2.77-bufferoverflow.patch to correct incorrect
  use of strncat. Reported upstream and already corrected in git.
* Mon Dec 28 2015 davejplater@gmail.com
- Added conditionals to enable blender to build without cycles and
  openCOLLADA for openSUSE:13.2 see boo#960234
* Fri Dec 18 2015 olaf@aepfle.de
- Use a build conditional for ffmpeg to enable it in Evergreen
* Tue Dec  8 2015 davejplater@gmail.com
- Removed libffmpeg-devel build requirement, ffmpeg-devel is now
  enough.
* Sat Dec  5 2015 davejplater@gmail.com
- Altered _constraints file to apply to all architectures.
* Fri Nov  6 2015 davejplater@gmail.com
- Spec file additions to allow build in other build service
  instances.
* Thu Nov  5 2015 mrueckert@suse.de
- update to 2.76b
  - Fix bug#46437: Make progress report py helper resitent to 'zero
    steps' passed value...
  - Fix bug#44048: freestyle lines in Cycles are in the wrong color
    space.
  - Fix bug#45152: multiviewithstereo render not working with
    Freestyle + Cycles.
  - Fix bug#46441: texture paint soften brush at 0 strength works
    at full strength.
  - Cycles: Increase number of textures allowed for OpenCL render
  - Fix bug#46444: Crash importing DAE with empty armature
  - Fix bug#46434: Shear with local-center & editmode fails
  - Fix bug#46446: texture nodes image node not working with image
    sequences.
  - Fix bug#46447: fix build on non-x86 platforms.
  - Fix bug#46458: BGE Crash on load
  - Fix bug#46450: Seams from islands, wont show 'Sharp'
  - Fix bug#46002: mathutils.geometry.intersect_line_line_2d
    doesn't operate on lines, but on line segments.
  - Fix bug#46467: Clean Keyframes removes the channels.
  - Fix bug#46453: JPEG quality not stored in file
  - Fix bug#46487: OpenSubdiv objects are invisible in Blender
    Internal "Rendered" viewport mode
  - BGE: Fix animations update when scene is suspended.
  - Fix bug#46223: multiview image sequences crashing.
  - Fix related to bug#46223: memory leak when loading multilayer
    multiview images.
  - Fix bug#46483: vertex/edge slide with correct UVs sometimes
    pinning UVs.
  - Fix bug#45900: Allow again white spaces in file names.
  - Fix bug#46465: Lag scrubbing with PlayAnim
  - Fix memory leaks in PlayAnim
  - Fix bug#46493: Wrong camera zoom blur with non-unit pixel
    aspect
  - Fix crash with PlayAnim & long filenames
  - Fix crash pressing +/- in file-selector
  - Fix bug#46503: Snap scale fails using corner pivot
  - Fix bug#46502: Linked dupli-group lost on reload
  - Fix for missing id_lib_extern, assigning ID's
  - Mesh remapping: fix loop 'best matching normals' not using
    transform space.
  - Fix bug#46508: data_transfer of normals fails in case objects
    are transformed.
  - Fix broken CD_NORMAL interpolation callback (would generate
    non-unit vectors).
  - Fix bug#46429: Movie clip is deformed by resolution multiplier
    when offset is added in sequence editor.
  - Fix bug#46524: Use Alpha (Straight/Premultiply) option missing
    in 2.76 for DDS files.
  - Fix bug#46520: mathutils.bvhtree crashes with distance input.
  - Fix bug#46531: Cannot use %% in filenames.
  - Fix bug#46529: Unwrap UV with use-subsurf fails
  - BGE: Fix bug#46381 : last action frame not updated.
  - Fix bug#46544: Can't unpack generated image
  - BGE: Fix physics meshes conversion with modifiers.
  - Fix bug#46524: Use Alpha (Straight/Premultiply) option missing
    in 2.76, part II.
  - Fix bug#46565: Movie render crash with out permissions
  - Fix bug#46561: Crash in outliner delete hierarchy
  - Fix bug#46569: Crash with mask & locked-track enabled
  - Fix bug#46521: Python: bvh.ray_cast doesn't find a plane facing
    in the other direction under certain circumstances
  - Cycles: Fix for watertight intersection
  - Cycles: Watertight fix for SSS intersection
  - BGE: Fix bug#46556: check on null sound datablock pointer.
  - Fix snap-scale with axis constraint
  - Fix for error with RenderView in ImageView list
  - Fix ffmpeg saving long paths
  - Fix ffmpeg memory leaks
  - Fix related to bug#46538: do not popup choice menu of
    mark/clear seam UV editor op invoke when prop is already set!
  - Fix bug#46538: Mark and Clear Seam in UV Editor, assigning
    Hotkeys.
  - Fix invalid exceptions with preview API
  - Fix error in bone UI
  - Fix: X-axis values in Graph Editor should not be displayed as
    timecodes in "Drivers" mode
  - Fix: Missing update after scrubbing time in Graph Editor
  - Fix bug#46599: Copy Rotation behaves erratically when Use Y is
    disabled
  - Fix: Prevent warnings from popping up when trying to edit
    driver expressions from buttons
  - Freestyle: minor speed-up by omitting the calculation of the
    smallest edge size.
  - Fix bug#46604: Crash in ChainPredicateIterator instantiated
    without predicates.
  - Fix broken comment about our WM progress report for python (its
    not a progress bar at all).
  - Fix bug#46606: Trackball Rotate jumps releasing shift
  - OpenSubdiv: Fix wrong handling of vertex parent
  - Fix bug#46605: Compositing causes access violation when
    rendering from command line
  - Fix bug#44231: Freestyle causes crash on render.
  - Freestyle: Fix for 'Distance from Object' modifiers without a
    target object.
  - Fix bug#46617 File Output Node seems to save only black images
    into OpenEXR image data
  - Fix for crash when saving OpenEXR Multi-View from Image Editor
  - Fix bug#46626: Crash generating previews
  - Fix bug#46622: crash with metas & particles
  - Fix bug#46651: Select linked crash with wire seam edges
* Tue Oct 27 2015 normand@linux.vnet.ibm.com
- disable WITH_CYCLES for PowerPC architectures to avoid
  build failure of cycles/bvh with missing x86intrin.h
  (not sure this is the best bypass)
  Add _constraints file to avoid no space error on ppc64le
* Mon Oct 26 2015 normand@linux.vnet.ibm.com
- avoid -msse* for PowerPC architecture
* Mon Oct 19 2015 davejplater@gmail.com
- Fix python3 search paths and build libmv alone in an attempt to
  fix x86_64 intermitent out of memory build failures.
- Added python3-requests to build requirements.
* Sat Oct 17 2015 davejplater@gmail.com
- Added python3-numpy-devel to build requirements.
* Sat Oct 17 2015 davejplater@gmail.com
- Added support for building against system audaspace.
* Mon Oct 12 2015 mrueckert@suse.de
- update to 2.76
  - Initial support for Pixar's OpenSubdiv geometry subdivision
    technology.
  - A huge view-port performance boost.
  - Big file browser performance boost and arrow keys navigation
    support.
  - Node auto-offset feature that helps organizing node layouts.
  - Absolute grid snapping in the 3D view.
  - Sculpting with tiled strokes.
  - Text effect strips for the sequencer, supporting subtitle
    export
  - As usual, hundreds of bugs fixed and other improvements!
    For more see http://www.blender.org/features/2-76/
* Tue Aug  4 2015 davejplater@gmail.com
- Enabled collada again after updating openCOLLADA to latest
  Fedora build.
* Sun Jul 19 2015 stephan.barth@suse.com
- Some spec file clean-up. graphviz and liblcms-devel were listed twice
- Make "-DWITH_OPENCOLLADA:BOOL=on" conditional, by using the value from
  "%%define collada". Only use it when not installing openSUSE openCOLLADA. At
  the moment the upstream version doesn't work.
- Update to version 2.75a
  Short list of upstream changes for 2.75
  - Blender now supports a fully integrated Multi-View and Stereo 3D pipeline
  - Cycles has much awaited initial support for AMD GPUs, and a new Light
    Portals feature.
  - UI now allows font previews in the file browser.
  - High quality options for viewport depth of field were added
  - Modeling has a new Corrective Smooth modifier.
  - The Decimate modifier was improved significantly.
  - 3D viewport painting now supports symmetry and the distribution of Dynamic
    Topology was improved
  - Video Sequence Editor: Placeholders can now replace missing frames of
    image sequences
  - Game Engine now allows smoother LOD transitions, and supports mist
    attributes animation
  - And: 100s of bug fixes and smaller feature improvements.
  The full list of features for 2.75:
  http://wiki.blender.org/index.php/Dev:Ref/Release_Notes/2.75
  A list of all bugfixes for 2.75 and 2.75a:
  http://wiki.blender.org/index.php/Dev:Ref/Release_Notes/2.75/Bug_Fixes
* Tue May 19 2015 stephan.barth@suse.com
- Update to version 2.74
  Short list of upstream changes:
  - Cycles got several precision, noise, speed, memory improvements, new
    Pointiness attribute.
  - Viewport has new cool compositing features, outliner now manages orphan
    datablocks better.
  - Modeling now allows custom normals, and transferring data layers between
    meshes!
  - Massive improvements to hair dynamics and editing tools: a big step forward
    with more to come...
  - A new tool “Cavity Mask” was added to  sculpting/painting, along with other
    improvements.
  - Great memory consumption optimization in Freestyle NPR stroke rendering.
  - Grease pencil and Game engine improvements, and more...
  See a full list of changes under:
  http://www.blender.org/features/2-74/
* Tue Mar  3 2015 davejplater@gmail.com
- Enable build with cycles - see bnc#905649
* Mon Feb 23 2015 khyota@redhyena.net
- Use SDL explicitly
* Sun Feb 15 2015 stephan.barth@suse.com
- Removed blender-freetype-2.5.4.patch
- update to version 2.73a
  Important upstream changes for 2.73a:
  * Fix invalid memory access in gradient brushes - could cause a crash
    in. (ae18fd5)
  * Fix crash in texture paint sampling when sampling materials
    without. (def2ef8)
  * Fix for GTest. (73955e2)
  * Fix texture sampling with generative modifiers - sample
    backbuffer. (b996871)
  * Fix for regression in bmesh connect-pair. (dec523d)
  * Fix T43204: Shrinkwrap constraint, project mode: Space ignored in bone
    case. (599c8a2)
  * Fix T43208 material flickering in edit mode. (1864253)
  * Fix BMesh regression: behavior for select more/less. (dcd662c)
  * Fix T43229: Knife-project regression (broke knife-project). (b77dd13)
  * Fix T43156: Cycles incorrect final render, proper viewport with moblur
    disabled. (3f0113b)
  * SDL wrangler: Support loading SDL2 libraries of different names. (653c6f2)
  * Sequencer: Don't crash when trying to rebuild proxy without having
    sequence edits. (1994e84)
  * Fix T43301: Three of the 'mirror keyframes' tools were mirroring along
    wrong axis. (6e97db7)
  * Fix own error in freestyle api. (704494e)
  * Bugfix T43293: Crash when editing shared GPencil datablock in
    VSE. (32ffc63)
  * Fix for security issue loading blend's. (45dfb3b)
  * Fix T43311: using displacement shader crashes blender. (7fd4c44)
  * Fix error in freestyle api. (967f93d)
- removed blender-freetype-2.5.4.patch, which is not necessary anymore
- create %%{_mandir}/man1 if it doesn't exist
- Update to version 2.73
  List of important new features from upstream:
  * User Interface
    + A new fullscreen mode without any buttons or other "annoying" elements
    to improve the UI
    + The 3D View got an option to display the world background right from
    the viewport
    + Pie Menus:
  - Confirm Threshold to confirm a pie menu without releasing the
    original key
  - Nested Pie Menus (a Pie Menu within a Pie Menu) are now supported
    + Chinese and Japanese complex character input
  * Modeling
    + Knife-tool:
  - Cuts can now be created using free-hand drawing
  - Cut-loops can now be closed by double click
    + Selection:
  - A new selection method "Select Similar Regions" was added
  - You can now skip adjacent faces while using the select more/less
    function
  * Sculpting/Painting
    + Texture Painting:
  - The Add Simple Uvs operator for texture painting now uses a simpler
    unwrap method for better quick UV layouts
  - Face-mask edges are now hidden to give proper visual feedback while
    working with masks
    + Brushes:
  - Changing brush size, detail size and strength can now be done using
    numeric keyboard input
  - Brush strength can now also be changed for Grab and Snake Hook
    brushes
  * Sequencer
    + A Backdrop similar to Compositor is now implemented for the Sequencer
    as well
    + Strips:
  - Strips can now be snapped to other strip's start- and endpoints
  - A new slip Tool allows moving content within the strip itself
  * Freestyle NPR Rendering
    + Freestyle got a new SVG exporter, implemented as an add-on
    + View maps can now be cached
    + More options for chain selection and chain sorting were added
  * Animation
    + Grease Pencil (which got a major upgrade):
  - It is now possible to edit and animate strokes (!!!)
  - New draw styles were added, e.g. filled stroke interiors, volumetric
    strokes, ...
  - The Grease Pencil's user interface (which is now completely defined
    via Python) has gotten a general overhaul
  - Two quick access pie menus were added
    + Graph Editor:
  - Revised the set of operators for showing/hiding curves from the
    keyframe area
  - Circle selection for Curves was added
  * Add-ons
    + Collada Importer:
  - Importing rigs previously caused problems with leaf bones (end bone
    of a bone chain) so a fix was created for that.
  - Added an experimental bonechain Finder to predict the longest
    possible chains of connected bones.
    + The FBX Add-on now uses some advanced handling/tweaking options for
    importing and exporting armatures
    + The Copy and Paste Add-on is now using version 2.0
  See full list of 2.73 features here:
  http://wiki.blender.org/index.php/Dev:Ref/Release_Notes/2.73
  All 2.73 and 2.73a bug fixes:
  http://wiki.blender.org/index.php/Dev:Ref/Release_Notes/2.73/Bug_Fixes
* Mon Dec 22 2014 dimstar@opensuse.org
- Add blender-freetype-2.5.4.patch: Silence warnings when building
  against freetype 2.5.4 (which has a structure change on FT_Bitmap).
* Tue Nov 18 2014 Led <ledest@gmail.com>
- fix bashisms in post scripts
* Thu Nov 13 2014 stephan.barth@suse.com
- Update to version 2.72b, which is like 2.72a a bugfix release
  A list of fixes can be found here:
  2.72a:
  http://wiki.blender.org/index.php/Dev:Ref/Release_Notes/2.72/Bug_Fixes#Blender_2.72a:_Bug_Fixes
  2.72b:
  http://wiki.blender.org/index.php/Dev:Ref/Release_Notes/2.72/Bug_Fixes#Blender_2.72b:_Bug_Fixes
* Mon Oct  6 2014 stephan.barth@suse.com
- update to version 2.71 to 2.72
  Changes from upstream (see full list with screenshots under
  http://wiki.blender.org/index.php/Dev:Ref/Release_Notes/2.72)
  - Cycles Rendering
    Volume rendering and Subsurface Scattering can be rendered with GPUs.
    Volume and Glossy sampling is improved.
    New Ashikhmin-Shirley distribution enhances Glossy and Anisotropic BSDFs.
    Memory usage during rendering is improved.
    OSL rendering is faster.
    Anamorphic Bokeh support added.
    Caustics are under better control.
  - User Interface
    The long awaited pie menus are available as an addon for ⇆ Tab, Z, Q, ⇆
    Tab⇧ ShiftCtrl, ., CtrlSpace operators.
    New Tooltip design makes important information more noticeable.
    Python text is displayed in a monospaced font.
    Blender Internal preview now behaves like the Cycles preview; it starts
    rendering at low resolution and improves from there.
    Units parsing has been improved, even though developers claim Blender does
    not feature a units engine, it does a better job now.
  - Modeling
    A new Intersection Tool was added to quickly cut up geometry. It's a bit
    like Boolean Tool, but, does not calculate interior/exterior.
    The Bevel Tool and the Bevel Modifier now have the option to set the
    material of the newly created faces to the material in a given slot.
  - Sculpting/Painting
    Texture painting workflow has been streamlined with easy access to painted
    images and UV layers.
    The ability to generate strokes with curves and lines has been added.
    More blend modes are available and new tools to fill and mask have been
    added.
  - Compositing
    A new Sun Beams node has been added to the compositor.
  - Game Development
    A new Mouse Actuator that can achieve a mouse look effect (among other
    things), has been added.
    The Property Sensor has new evaluation types.
    The TrackTo Actuator has new menus to select up/track axis.
    The Property Actuator has a new level mode.
    The Mouse-Over-Any Sensor has new X-Ray and Property/Material detection
    options.
    A new BGE Debug and Contraints Wrapper API have been added.
  - Freestyle NPR Rendering
    The Freestyle line rendering engine has been integrated into Cycles in
    addition to the Blender Internal (BI). Freestyle provides Cycles users
    with a versatile non-photorealistic (NPR) line rendering solution. Most
    Freestyle options work in the same way for both Cycles and BI. Line
    textures in Freestyle for Cycles are defined by means of shader nodes
    (unlike Freestyle for BI, which relies on the conventional texture mapping
    and influence panels). New per-material Freestyle line settings provide a
    reliable mean to specify line colors applicable to both Cycles and the
    BI. The Freestyle Python API also has user-visible updates for better code
    readability and run-time performance.
  - Animation
    More Features
    Color ramps now support color interpolation in hue mode both clock-wise
    and counter-clock-wise.
    CtrlF in Animation Editors, is a convenience shortcut to activate Filter
    by Name functionality.
    Weights now draw in wireframe mode in the 3D view.
    Temporary data gets deleted when closing Blender.
    The Video Editor has a new Gaussian blur filter.
    New camera presets: Blackmagic Pocket Cinema and Blackmagic Production
    4K.
  - Addons
    FBX improvements: Import now supports armatures, shapekeys, animations,
    with shapekeys also being supported for export.
    New DXF importer supports 3D(SubD) geometry, and geo-referencing. It
    imports curves as curve obkects and adds control over various geometry merge
    options.
    New UV addon for align distribution and copy/paste (!!) of UVs.
    New Game Publishing Addon is available for game developers!
    New addon for named layers & grouped layer management.
* Wed Jul  2 2014 stephan.barth@suse.com
- Introduced hard build requirement for Python3 >= 3.4, because otherwise it
  won't build anymore.
- Adjusted Python 3 path for building 13.1, which doesn't build anymore anyway
- Fixed some minor spec file entries, because version string in the tarball
  changed again
- update to version 2.71 from 2.70a
  Most important changes from upstream (see full list under
  http://wiki.blender.org/index.php/Dev:Ref/Release_Notes/2.71)
  - Animation
    More easing equations added to the IPO editor for better animation
    control, locking time to other windows is again possible, auto snapping is
    now independent from display type.
    The user interface now offers more feedback, especially on errors, updates
    driver expressions automatically on editing, includes more icons and
    offers more editing tools.
    New tools also include lasso selection support, non-linked duplication for
    strips, and setting preview range based on selected strips.
  - Modelling
    The new per-face normals feature allows blender to display and export
    sharp edges correctly without geometry duplication.
    In addition, selection tools offer more options.
  - Sculpting/Painting
    New features include a HSL color wheel for color selection and tools to
    handle homogenous density in dynamic topology sculpting.
    Dyntopo and matcap display for sculpt mode have also had performance
    optimizations.
  - Game Engine
    UI to deactivate logic bricks, multi-threaded animations, shadows-only
    materials and more action layers are among the new features for the game
    engine
  - Freestyle NPR Rendering
    Freestyle has been upgraded with textured stroke support. Textured stroke
    support makes it possible to apply patterns to the lines and simulate
    rough surfaces or different kinds of brush tips for the strokes
    themselves.
    Line sorting also gives artists more control over the order of line
    drawing
  - User Interface
    Interface features include new icons for texture painting, resizeable
    preview widgets and draggable popups.
  - More Features
    More control for curve bevelling, explicit shadow cast control for blender
    internal materials, new distortion model for motion tracking and better
    handles for mask editors.
* Mon Apr 14 2014 stephan.barth@suse.com
- update to bugfix version 2.70a
- fixed some paths in the spec file to reflect version number differences
* Tue Apr  8 2014 stephan.barth@suse.com
- Added "Exec" and "Categories" lines to x-blend.desktop (bnc#848910)
- Check x-blend.desktop with desktop-file-validate
* Wed Apr  2 2014 stephan.barth@suse.com
- update to version 2.70
  Upstream changes:
  + Volumetric rendering support has been added to Cycles
  + motion tracking now supports weighted tracks
  + many user interface improvements have been made
  + New threaded dependency graph evaluation has been added
  + a laplacian deform modifier and a wireframe modifier have been added as
    well
  + many improvements to the existing toolset
  + over 560 bugfixes
- Fixed building for Python 3.4
- Delete .gitignore file
- Extended fdupes call to remove locale duplicates
- Rewrote file liste to avoid duplicate files in main and lang package. Also
  explicitly name directories.
- removed blender-2.64a-fix-locale-files-path.patch
  This patch is not needed anymore. locales are now installed in the correct
  path out of the box now.
* Wed Jan  1 2014 coolo@suse.de
- add constraints file to avoid building on low memory (needed for
  x86_64, but it can't be limited to that arch)
* Sun Nov 17 2013 badshah400@gmail.com
- Update to version 2.69 (for the full list see
  http://wiki.blender.org/index.php/Dev:Ref/Release_Notes/2.69):
  + Modeling:
  - A new hidden wire display option was added to help with
    retopology
  - Mesh Bisect is a new tool to cut meshes in half
  - The Bridge, Edgenet fill, Grid fill and Symmetrize tools
    were improved
  - New curve and lattice editing tools were added too
  + Cycles Rendering:
  - Hair rendering was improved with a new Hair shader and
    reorganized settings
  - Subsurface scattering uses a new sampling algorithm and now
    supports bump mapping and texture blurring
  - Sky rendering now uses a more accurate sky model
  - New blackbody, vector transform and HSV nodes were added
  - The non-progressive integrator was renamed to Branched Path
    Integrator, and is now available for GPU rendering
  + Motion tracker now supports plane tracking, which can be used
    to replace billboards, screens and other flat things in
    footage
  + Lists in the user interface can now be resized, sorted and
    filtered
  + Small improvements for vertex parenting, empty objects, the
    shrinkwrap modifier, mask editing, armatures, f-curves and
    drivers
  + Addons:
  - FBX Import support has been added
  - FBX/OBJ can now export split normals (without the need for
    the edge split modifier)
  + Fixes for over 270 bugs.
* Mon Oct 21 2013 hrvoje.senjan@gmail.com
- Disable sse2 instructions on non x86_64 arches, bnc#846545
* Fri Sep 13 2013 badshah400@gmail.com
- Update to version 2.68a:
  + Bugs fixed:
  - Fix #36218: Crash deleting a sequence strip
  - Fix #36216: Viewport render with CMJ sampler and unlimited
    passes freezes
  - Fix #33016: BGE, Blender crashes on Game Engine start
  - Fix #35195: BGE, Shadow Only lamps only work with Specular
    enabled
  - Fix #36227: removing vertex colors crashes
  - Fix #36223: BGE, fix crash with Game actuator
  - Fix BGE, incorrect exception for
    SCA_JoystickSensor.axisSingle access
  - Fix #36234: Dynamic Topology undo crash
  - Fix #36224: Cloth Simulation Doesn't Work on Rearranging
    Modifiers
  - Fix #36240: Painting Undo Enable Face paint Crash
  - Fix #36248: Crash using factor input on color mix node
- Changes from version 2.68:
  + See detailed release notes at
    http://wiki.blender.org/index.php/Dev:Ref/Release_Notes/2.68
- Use proper source URL for source tarball.
* Mon Jun 17 2013 kshkss@gmail.com
- Update to version 2.67b
- Remove blender-2.66a-bigendian.patch, fixed upstream.
- Upstream bug fixes see :
  http://wiki.blender.org/index.php/Dev:Ref/Release_Notes/2.67a and
  http://wiki.blender.org/index.php/Dev:Ref/Release_Notes/2.67b
- Upstream changes for 2.67 see :
  http://wiki.blender.org/index.php/Dev:Ref/Release_Notes/2.67
* Fri May 24 2013 dvaleev@suse.com
- Fix build on Big Endian platforms (blender-2.66a-bigendian.patch)
* Wed May  1 2013 davejplater@gmail.com
- Update to version 2.66a
- Removed blender-2.64a-big-endian.patch and
  blender-2.64a-libpng16.patch, fixed upstream.
- Upstream bug fixes see :
  http://wiki.blender.org/index.php/Dev:Ref/Release_Notes/2.66a
- Upstream changes for 2.66 see :
  http://wiki.blender.org/index.php/Dev:Ref/Release_Notes/2.66
- Upstream changes since 2.64a see :
  http://wiki.blender.org/index.php/Dev:Ref/Release_Notes/2.65 and
  http://wiki.blender.org/index.php/Dev:Ref/Release_Notes/2.65a
* Sat Mar 16 2013 schwab@linux-m68k.org
- Build with $RPM_OPT_FLAGS
* Mon Mar 11 2013 cobexer@gmail.com
- fixed %%postun script error
* Mon Mar  4 2013 schwab@linux-m68k.org
- Make compile commands visible to check_gcc_output
* Tue Feb 19 2013 pgajdos@suse.com
- build also with libpng16
  * libpng16.patch
* Mon Nov  5 2012 Rene.vanPaassen@gmail.com
- need buildroot for SLED
- need to define PYTHON_LIBPATH etc for SLED also
- modified desktop file installation for SLED
* Thu Nov  1 2012 dvaleev@suse.com
- fix big endian build (blender-2.64a-big-endian.patch)
* Mon Oct 29 2012 p.drouand@gmail.com
- Update to version 2.64a:
  + See
    http://www.blender.org/development/release-logs/blender-263/
    for upstream changes.
- Update fix-locale-files-path patch for 2.64 version
- Remove unneeded fedora conditional macros
- Add python3 version option on configure cmake
- Add a patch to correct python development files on Factory
- Fix build for Factory
* Fri Sep 21 2012 idonmez@suse.com
- Add explicit glu dependency
* Mon Jul 30 2012 coolo@suse.com
- just use default libjpeg on opensuse
* Thu Jun 21 2012 Rene.vanPaassen@gmail.com
- Need a BuildRoot: defined, for building on SLE 11
* Fri May 11 2012 badshah400@gmail.com
- Update to version 2.63a:
  + See
    http://www.blender.org/development/release-logs/blender-263/
    for upstream changes.
- Add blender-fix-locale-files-path.patch to fix the path where
  locale files are installed. Split out a lang package with extra
  locale files.
- Do not enable verbose make file logs.
* Thu May  3 2012 davejplater@gmail.com
- Used Fedora 2.62 src rpm packaged by Richard Shaw to update to
  version 2.63
- Patch blender-2.62-blenkernel.patch no longer needed upstream
  remove all undistributable directories if ffmpeg is disabled or
  not available.
- blender-collada858.patch no longer needed, fixed upstream
- blender-gcc47.patch no longer needed, fixed upstream
- Blender now fully compatible with "second life" see bnc#652536
- See http://www.blender.org/development/release-logs/blender-263/
  for upstream changes.
* Wed Apr 11 2012 dimstar@opensuse.org
- Add blender-collada858.patch: openCOLLADA >= svn 858 installs
  the headers to /usr/include/COLLADA* instead of
  /usr/include/COLLADA*/include, thus messing up the build of
  blender.
- Add blender-gcc47.patch: Fix build with gcc 4.7. Taken from
  upstream svn, r44000.
* Wed Sep  7 2011 davejplater@gmail.com
- Update to release 2.59, added patch
  blender-2.59-colladainclude.patch to correct build.
- Upstream changes:
  * This is mostly a bug fix release with 140 fixes since 2.58a.
  Additions include improved keymap editing, 3D mouse support,
  some new addons and Node UI improvements.
  too numerous to list all please refer to:
  http://wiki.blender.org/index.php/Dev:Ref/Release_Notes/changelog_259
* Tue Sep  6 2011 davejplater@gmail.com
- Added "Requires: python3-xml to fix bnc#713346
* Wed May  4 2011 davejplater@gmail.com
- Created blender-2.57b-nobuffer_ftoa_utf_link.patch to stop
  blender's linker looking for libs buffer, ftoa and UTF from
  openCOLLADA as these libs are now static included in the other
  libraries and no longer exist.
* Thu Apr 28 2011 davejplater@gmail.com
- Update to blender-2.57b Release.
- Fix new patch blender-2.56-gcc46.patch to apply cleanly.
- Upstream changes :
  * The Blender Foundation and online developer community is proud to
  present Blender 2.57a. This is the first stable release of the
  Blender 2.5 series, representing the culmination of many years of
  redesign and development work.
  * We name this version "Stable" not only because it's mostly feature
  complete, but especially thanks to the 1000s of fixes and feature
  updates we did since the 2.5 beta versions were published.
  * The next 2 months we will keep working on finishing a couple of
  left-over 2.5 targets and we expect to get feedback and bug reports
  from users to handle as well. If all goes well, the 2.58 version
  then can be the final release of the 2.5 series, with a massive
  amount of new projects to be added for an exciting cycle of 2.6x
  versions. Target is to release updates every 2 months this year.
* Thu Apr 28 2011 idoenmez@novell.com
- Add blender-2.56-gcc46.patch to fix compilation with gcc 4.6
* Sun Apr 17 2011 davejplater@gmail.com
- Update to blender-2.57 stable
- Upstream news :
  The Blender Foundation and online developer community is proud to
  present Blender 2.57. This is the first stable release of the
  Blender 2.5 series, representing the culmination of many years of
  redesign and development work.
  We name this version "Stable" not only because it's mostly feature
  complete, but especially thanks to the 1000s of fixes and feature
  updates we did since the 2.5 beta versions were published.
  The next 2 months we will keep working on finishing a couple of
  left-over 2.5 targets and we expect to get feedback and bug reports
  from users to handle as well. If all goes well, the 2.58 version
  then can be the final release of the 2.5 series, with a massive
  amount of new projects to be added for an exciting cycle of
  2.6x versions. Target is to release updates every 2 months this year.
* Thu Apr 14 2011 davejplater@gmail.com
- Update to blender-2.57.36147 2.57 release.
- For upstream changes see :
  /usr/share/doc/packages/blender/Changes.txt
* Thu Apr  7 2011 davejplater@gmail.com
- Update to blender-2.57.36007
- For upstream changes see :
  /usr/share/doc/packages/blender/Changes.txt
* Mon Apr  4 2011 davejplater@gmail.com
- Update to blender-2.57.35927
- For upstream changes see :
  /usr/share/doc/packages/blender/Changes.txt
* Wed Mar 23 2011 davejplater@gmail.com
- Update to blender-2.56.35927
- For upstream changes see :
  /usr/share/doc/packages/blender/Changes.txt
* Tue Mar 22 2011 davejplater@gmail.com
- Update to blender-2.56.35701
- For upstream changes see :
  /usr/share/doc/packages/blender/Changes.txt
* Tue Mar  8 2011 davejplater@gmail.com
- Update to blender-2.56.35402
- Enable blenderplayer to build
- For more changes see :
  /usr/share/doc/packages/blender/Changes.txt
* Mon Mar  7 2011 davejplater@gmail.com
- Update to blender-2.56.35390
- Upstream changes :
  * fix for building with opencollada 833 on linux.
  For more changes see :
  /usr/share/doc/packages/blender/Changes.txt
* Thu Feb 17 2011 davejplater@gmail.com
- Update to blender-2.56.34784
- For upstream changes see /usr/share/doc/packages/blender/Changes.txt
* Sat Feb 12 2011 davejplater@gmail.com
- Update to 2.56 beta svn snapshot blender-2.56.34
- Upstream changes:
- *Bugfixes: #26021, #26039, #26040, #25973, #25978, #26030
  [#26013], #26001, #26004, #26002, #26007, #25831, #25968, #25523,
  [#25969], #25957, #25977, #25975, #25693, #25801, #25970, #25965,
  [#25963], #25926, #25955, #25934, #25951, #25953, #25937, #25824,
  [#25947], #25948, #25693, #25944, #25608, #25871, #25923, #25933
  * For many new features and 2.49 functionality restored see :
  /usr/share/doc/packages/blender/Changes.txt
* Sat Jan  1 2011 davejplater@gmail.com
- Update to 2.56 beta svn snapshot blender-2.56.34000
- Upstream changes :
  The Blender Foundation and online developer community is proud to
  present Blender 2.56 Beta. This release is the fourth official
  beta release of the Blender 2.5 series, representing the
  culmination of many years of redesign and development work.
  This version is called a "Beta" because it's now for the most
  part feature complete. The Python API has had some extensive
  changes, most notably in naming conventions and in creation and
  access of properties.
  Since Blender 2.55 beta over 440 bugs were fixed!
* Tue Dec 14 2010 davejplater@gmail.com
- Update to svn snapshot blender-2.55.33653
- Upstream bugfixes :
  [#25211], #25209, #23922, #23826, #25207, #23420, #25191, #25197,
  [#25199], #25178, #25184, #25185, #25188, #24752, #23395, #25186,
  [#25183], #25179, #25177, #22967, #25071, #22477, #25106, #25170,
  [#25153], #25095, #25135, #25116, #25155, #25154, #25159, #25027,
  [#25150], #25147, #25120, #25119, #25104, #24814, #20598, #25099,
  [#25086]
- Upstream changes :
  * New math util funcitons:
  equals_v2v2
  project_v2_v2v2
  isect_seg_seg_v2_point
  which would be necessery for my further multires interpolation
  commit
  * M_Geometry_LineIntersect2D now uses isect_seg_seg_v2_point().
  * Behaviour of this function was changed a bit -- it haven't
  returned intersection point in several cases when two segments
  are making angle.
  * 2.4 feature back:
  For constraints that have 'disabled' flag (because it has
  invalid input) the name was drawn in red. Easy to recognize
  constraints that stopped working.
  * Moved extensions_framework into addons/modules
* Wed Dec  8 2010 davejplater@gmail.com
- Update to svn snapshot blender-2.55.33554
- Upstream changes :
  * Bugfixes #25023 #25003 #25060 #21246 #25073 #25076 #25074
  [#25049] #24163a #25085 #25079 #25088 #25081 #25082 #24052
* Mon Dec  6 2010 davejplater@gmail.com
- Update to svn snapshot blender-2.55.33504
- Upstream changes :
  * CMake: use a global list to store libraries built rather then
  cmake_blender_libs.txt file
  * bugfixes [#24967] [#24995] [#25057] [#25030] [#25046] [#25047]
  [#22663] [#25050] [#25041] [#25042] [#25036]
  * Fixed memory leak in thumbnail_joblist_free
  * fix for camera border going outside the clipping range while in
  camera view.
  * use constant strings for outliner menus rather then sprint'ing
  them together.
  * Fixed dead-lock when subviding curve
  * use PyUnicode_DecodeFSDefault rather then
  PyUnicode_DecodeUTF8(str, strlen(str), "surrogateescape"),
  for converting non utf8 names.
  * extensions_framework: prefer user config and scripts dirs, if
  set, to save addon config files to.
  * Dependency graph: changed DAG_id_flush_update to
  DAG_id_tag_update.
  * bpath iterator updates
  * use BLI_strnlen rather then strlen when comparing against fixed
  lengths.
* Sat Dec  4 2010 davejplater@gmail.com
- Update to svn snapshot blender-2.55.33472
- Upstream changes :
  * Bug fix #21900, Bugfix #21893, Bugfix #24699, Bugfix #25033
  * Give functions that use printf style formatting GCC format attributes
  so if incorrect formatting is used the compiler will warn of this.
  * minor changes to bone UI script.fix for strict prototype error.
  * remove shadowed definitions but keep them as zero this time.
  * Const conflict in PIL_dynlib_find_symbol
  * Bugfix #2508, Bugfix #24568, Bugfix #25026, Bugfix #24999
  * Curve editmode was missing hotkey for operator "Select Inverse"
  Is now added like Mesh, CTRL+I
  * Text editor, "Add new" caused zero-user block.
  * Nurbs edit: 'switch order' crashed when order was higher than amount of
    points.
  * Fix for compilation error caused by strict prototype checking
  * Fix #25017: Bezier Curve Deform Twisting after adding Shape Keys
  * Bugfix #20565, Bugfix #24890, Bugfix #24903, Bugfix #25010
  * Fix for [#24899]Align Objects operator was broken due to incorrect order of vector by
  matrix multiplication
  * updates to patch from Dan Eicher, allow adding a NodeGroup through bpy.data.node_groups.new(name, type)
  * fix [#24938] Seed value on Particle settings gives Error when trying to insert key.
  * fix [#25015] Ctrl+L linking to scene list does not scroll when the list is larger than screen resolution
  correction to error message from Dan Eicher
  * fix crash when report timer was set but no usable error reports were found.
  * Fix for [#25006] Particle system crash (missing check for negative index)
  * bugfix [#24913] Text bevel normals wrong
  * Fix for [#25001] Enable Smoke High Resolution is greyout after baking
  * Additional fix for #24958 Cloth pinning not working
  * Adding some descriptions for animation-related operators that were missing them.
  * patch [#23212] Python api for Nodes
  * fixed crash with rigid body constraints not having their child pointer read correctly.
  * Fix for [#24958] Cloth pinning not working
* Wed Dec  1 2010 davejplater@gmail.com
- Update to svn snapshot blender-2.55.33410
- Upstream changes :
  * fix for crashes trying to resolve paths "location[]" or "location.."
  * increase the reference counts when setting default scene compo nodes
  else removing them can set the user count < 0.
  * quit blender if the first X11 window fails to open.
  mainly just to avoid a segfault so the user knows its not a bug.
  * workaround [#24958] Cloth pinning not working
  * bugfix [#23406] DPX Images load darker then saved, UI broken.
  * patch from JacobF on IRC, copy smoke settings. double checked none
  of these are used for runtime.
  * bugfix [#22638] Alpha channel not saved when using texture paint
  * minor console changes.
  remove report argument from console functions.
  don't update the scroll area while drawing, do this within operators instead.
  dont redraw while selecting text unless selection changes.
  * bugfix [#23423] Multi-window : closing game windows cause blender crash
  * Smoke now uses only one point cache where both normal and high resolution smoke are stored together:
    Separate caches were causing quite a lot of problems both in principle and practice.
    For example it doesn't really make sense to have different frame ranges for normal and high resolution smoke, but this was fully possible before.
    Also to fully bake the smoke you had to do a "Bake All Dynamics", which completely defeats the whole point of the feature!
    As a result of this change the smoke cache usage is much much simpler and less error prone.
    This is quite a big change, but hopefully there should be less rather than more problems as a result :)
  Some other related changes:
    Changing the cache name now works for disk caches properly too, it
    now just renames the cache files so should be faster too!
    Smoke is now always forced to disk cache with step 1 on file load
    as there were some strange cases where smoke was trying to use memory cache.
    Disabled smoke debug prints from console.
    Disabled changing smoke parameters when smoke is baked.
  * misc small changes.
    commented unused View3D->flag's
    popup dialog now centers over the mouse
    only overwrite image alpha with render settings on save if saving the render result.
  * Bugfix #24986 bugfix [#24974] bugfix [#24798] Bugfix #24976 fix [#24990]
* Mon Nov 29 2010 davejplater@gmail.com
- Update to svn snapshot blender-2.55.33375
- Upstream changes :
  * fix for error when changing DISBALE_PYTHON -> WITH_PYTHON,
  * Fix [#24964] HISTOGRAM: Inconsistency in spaces
  * Fix [#20241] half-transparent objects in volume have no shadow.
  * include headers in cmake source, added a script to check for
  consistency, reporting missing headers & C files.
  * Fix: [#24170] Camera inside volume error, [#24838] Light inside
  Volume material drops on it's walls - it may be double
  * fix [#24921] Crash after inserting keyframing UV coords and
  changing frame in edit mode zero length arrays were still having
  their members accessible.
  * bugfix [#24947] Animations data replaced by the first animation (fbx exporter)
  * Bugfix #24933
  * Bugfix #24953
  * bugfix "Export UV Layout" stalls when saving file in 2.55b
  * fix for fix [#24955] Generating UV-Images within blender (Alt-N) not possible
  * Detect Gallium driver. Extend NPoT workaround to opensource drivers.
  * Bugfix #21385
  * [#24935] Proportional translation size stuck to none
  * bugfix [#24944] Crash on attempting to keyframe HSV color prevent eternal loop
  * console text underscore would draw outside the view for larger font sizes.
  * fix for fix r33330, bug [#23118].
  * Particle draw was calling glColorMaterial(...) after glEnable(GL_COLOR_MATERIAL),
  * added option to turn off Text anti-aliasing in the UI
  * Fix #24914: 3D text glitch and crash
  * remove support for rna resolving paths with collection['name'],
  only support collection["name"],
  * Rigid Body Joint Constraint:
  * Update nurb keyindex data when subdividing
  * fix building blenderplayer and a divide by zero bug with the console view.
  * "Fix" for [#24934] Particle single user crash
  * Bug fix: voxeldata texture extension didn't work.
  * lasso select wasn't comparing the depth with particle selection, where border and circle select do.
  * bugfix [#23118] Blender freezes when combing hair - OS X path changes related?
  * freeing all free GPU buffers every frame could be a performance issue and is not necessary
* Fri Nov 26 2010 davejplater@gmail.com
- Update to svn snapshot blender-2.55.33326
- Upstream fixes :
  * follow up of "Bugfix #23576" (Logic UI)
  * Fix #24855: disabling shadows didn't disable AO/env with ray transparency
  and AO multiply mode.
  * BGE Bugfix: [#24926]
  * Fix #24923: tweak falloff strength tooltip to apply both to AO and indirect.
  * Fix #24775: boolean modifier crash in rendering on Mac. Problem was that this
  ran out of stack memory, now it passes some arguments by reference instead of
  by value to use less stack space.
  * ATI X1xxx gfx cards (R500 chipset) lack full support for npot textures
  although they report the GLEW_ARB_texture_non_power_of_two extension.
  * Smoke domain resolutions were calculated wrong for non-cube domains in some cases.
  * bugfix while looking into [#24900], color wasn't being set for face-mask mode.
  * bone roll recalculate, option to use active bones Z axis.
  * bugfix [#24907] bone roll z up broken and python script showing correct
  method to roll bones
  * Fixed bug with Text menu in font edit mode
  * fix for https://projects.blender.org/tracker/index.php?func=detail&aid=24442&group_id=9&atid=498
  * [#24442] GLSL + VBOs
  * bugfix [#24916] Blender Crash after inappropriate Merge-Command
  * Redraw 3d view when new object was added (NC_OBJECT|NA_ADDED notifier)
  This fixes one issue from #24914: 3D text glitch and crash ("delayed" 3d view refresh)
  * Possible fix for the issue that came up in [#24890] Vector Blur node is Buggy
  * Fix polling order for ui panels in netrender.
  * Spline IK Bugfix:
  * drivers could reference invalid index values outside the bounds of the array.
  * define UNUSED() locally for mmap_win
  * fix for crash introduced r33257, also tag some vars as unused.
  * fix [#24893] Minor error message glitch
  * bugfix [#24884] Loading any preset leads to crash
  * bugfix [#24887] Crash on snapping verts on other object
  * close addon files, Py3.2 now complains when files are left open.
  * Bugfix #24887
  * fix for crash canceling fly mode.
  * Bugfix #24847
  * add a window manager to files loaded from 2.4x in background mode.
  (partial fix for [#24882]).
  * Bugfix #23576
  * Fix #24782: proxy armature Layer state not saved with file. Was in 2.4x but
  not ported to 2.5x, implemented a bit different now to fit RNA better.
  * fix [#24879] "Feather" symmetry option in sculpt mode crashes.
  * rotate_m4() was being called with axis=0
  * Fix for [#24877] Cloth + hair bug
  Particles needed the original index layer, but didn't ask for it.
  * Fixes for [#24862] Fluid Simulator issues
  * bugfix [#23871] OSX panel button bug (Python Namespace issue)
  * Remove library specification.
* Wed Nov 24 2010 davejplater@gmail.com
- Update to svn snapshot blender-2.55.33275
- Upstream changes :
  * When exporting images also add the string name (attribute). This
  is optional, but it helps other viewers importing from Blender
    .dae exports.
  * Fix #24834: curves extrude + bevel gave bad normals on rendering.
  * Small feature fix: zero-user blocks get indicated with "0" again
  in browsing.
  * Previous commit cleaned up one variable too many, breaking
  adding torus/tube in Nurbs editmode.
  * Bugfix #24860
  * use unit system for the grid floor (was only ortho before).
  * minor edits to exception formatting (remove . or \n from suffix)
  * bugfix [#24871] Unwrapping with Smart Project give a bad result.
  * fix for typo in mathutils vec.to_track_quat() argument parsing.
  * Changed some ui names for smoke parameters to make things less
  ambiguous.
  * Fix for [#19706] Smoke 'sticks' to Collision objects initial
  position
  * Changes to the ortho grid drawing based on discussion with Ton.
  * Cached smoke wasn't being drawn on file load before going to
  simulation start frame.
  * transform snapping to a unit scaled grid was broken.
  * fix [#24870] ObjectActuator.offset_rotation in radians
  * partial fix for [#23532]
  * Particle fluid and boid settings didn't have a valid rna path,
  so they couldn't be animated.
  * use zero initializers instead of memset(), also change
  PointerRNA_NULL from an extern into a define.
* Tue Nov 23 2010 davejplater@gmail.com
- Update to svn snapshot blender-2.55.33249
- Upstream changes :
  * extensions_framework: fix UI  drawing logic
  * Partial fix for #24773: Material Nodes - there isn't able to set keys on Mapping coordinates
  * Playback now works.
  * fix for player with recent update.
  * fix for cmake if build flags are not defined.
  * Fix #24596: specular toggle on material didn't work correct.
  * fix [#24866] object/transform/align objects error
  * bugfix [#23609] Lamp PointerProperty, Bugfix #24823
  * More button alignment stuff: campbell had a script that was
  drawing various cases. Fixed another one.
  * Bugfix #24856; bugfix [#24805] bpy operator runs in wrong order or is ignored at all
  * fix for triangulate OBJ export option. reworked fix from Radu Danciu
  * bugfix [#20768] Project Snap Broken rna invoke function wm.invoke_confirm() for python access.
  * find filepaths operator had blend file and search path swapped.
  * blend_m3_m3m3 and blend_m4_m4m4 now support matrices with negative scales.
  * python/mathutils api matrix.lerp(other, factor)
  * new function mat3_to_rot_size(), like mat4_to_loc_rot_size but with no location.
  * fix for fix r33219, reports. Set a valid WM after running UNDO.
  * [#24849] changing objects to another layer causes segmentation fault
  * [#24848] Using an operator outside of edit mode crashes blender
  * [#24844] Crash related to the subdivision (aka subsurf) modifier
  * [#24843] ctrl+z crashes blender
  * rename hide_tooltips_python to show_ ..., tag unused variable with recent sequencer commits.
  * User preference to hide Python references in Tooltips.
  * Fix: 8bit raw and 'blender voxel' voxel data texture formats didn't support relative paths
  * documented and rewrote the render interface of the sequencer.
  * Toggle cyclic on when creating segment between first and last points of non-cyclic bezier
  * Recalc handles after toggling bezier's cyclic flag when deleting segment
  * Applying patch #24822: Select linked for curves as for meshes, CTRL + L version
  * Bugfix #22611, [#22854] Objects lag behind mouse pointer when transformed (translated)
  * [#24652] Project vertices button showing in object mode and leads to wrong behavior.
  * Bugfix #24837, Bugfix #24825. disallow disabling WITH_SAMPLERATE if any audio outputs are enabled.
  * WITH_SAMPLERATE option for cmake.
  * Fixed missed selection oulines for curves/surfaces/fonts/armature when texture shading is active
  * patch from Mike S to enable OpenMP and xcode
  * Bugfix #24824. some more rna range corrections
  * correct exception messages for mathutils constructors.
  * incorrect argument parsing for python opengl module bgl.
  * unsigned byte/short/int were being passes as signed values which would
  * raise an overflow error if a range greater then the signed value was used.
  * fix for RNA ranges exceeding the range of the type.
  * [#24827] Crash when auto-keyframing while playing animation. Bugfix #24792
  * Fixed bug #20620, "VertColors and Flat/Soft imported from 2.49 are wrong
  * Bugfix #21028. Bugfix #24801. Bugfix for [#24768] 6DoF Constraint options missing.
* Tue Nov 16 2010 davejplater@gmail.com
- Update to 2.55.33093
  * Fix [#24310] With high poly numbers when sculpting, modifier keys hang
  reported by Eclectiel L
  When working with very heavy scenes Blender can seem to 'hang' (not responding). Key events that happen
  during this period may get lost, especially for modifier keys.
  Adding extra handling to account for these situations.
  * bugfix [#24696] Export OBJ - Selection Only toggle button has the wrong default state.
  Added convenience function to operators, 'as_keywords()', so operator settings can be passed directly to a function as keyword arguments.
  The problem in this case was that dictionary access to operator properties was not returning rna-property defaults, so as_keywords() ensures all defaults are set.
  * Bugfix, reported in IRC
  The enum "rotmode" was read using an array, without checking for boundary
  cases, causing crashes on bad input. (Wahooney report 2, thanks!)
  * Bugfix #24726
  Doing F1-load a lot of times on same .blend could crash.
  Janne karhu provided a potential fix, which is good to add
  anyway. Will ask him to verify too.
  Added XXX warning for these lines, after filesel exec no
  context variables should be re-used. Is for later investigation.
  * fix for fix, r33086.
  - incorrect range check broke ZYX euler rotations, use MIN/MAX constants so this doesn't happen again.
  - BGE Armature PyAPI also wasn't using correct min/max with rotation modes.
  - clamp on file read rather then when calling the rotation functions, so developers don't use invalid args without realizing it.
  - added assert() checks for debug builds so invalid axis constants don't slip through.
  * patch #24737] PyCObject depreciated in py3k [patch]
  from Dan Eicher (dna), use PyCapsule rather then PyCObject
  * patch [#24742] materials.pop() doesn't decrement user count
  * from Dan Eicher (dna)
  * fix for matrix * vector rotation order.
  * FBX Export, small changes made while looking into reported bug. (no functional changes)
  - Warn for armature deformed meshes which are scaled, these don't work quite the same as in blender, reported as [#24663].
  - Use matrix.decompose() to convert a matrix to loc/rot/scale.
  - get vert/edge/face lists for each mesh only once.
  - faster euler rad -> deg conversion function.
* Mon Nov 15 2010 davejplater@gmail.com
- Update to svn version 2.55.33084
- Upstream changes :
  * bugfix [#24660] (vector * matrix) fails, (matrix * vector) succeeds
  * bugfix [#24665] mathutils.Matrix initialization is counter-intuitive and generates bugs
  was printing transposed, also nicer printing.
  * Getting BLF to work with the Blenderplayer.
  * take delta's into account when applying the objects matrix (dloc, drot, dsize).
  * Now object_apply_mat4() can be used as the reverse of object_to_mat4().
  * add back red tint for zero user datablocks.
  * bugfix [#24682] Render artifacts with mat node
  * Related to #24653: added scene.collada_export() function, to use instead of an
  * operator for external render engines, since operators should not be called in
  * the render() callback.
  * Hide "active" checkbox in ui for "fluid" type fluid objects as it's not used by fluidsim.
  * * Response to report [#24670] Keyframe fluid on/off does not work
  * Bugfix #24335
  * bugfix [#24661] Object.find_armature() only works on meshes
  * Makefile fix for compiling with quicktime.
  * Bugfix #20382
  * Fix for [#24654] Sound Actuator doesn't find the file when Blender is reopened.
  * Patch [#21942] Node links access by Andrey Izrantsev (bdancer) Thanks!
  * update for mathutils vector/matrix order change.
  * fix for own error in recent commit. add a back NULL terminator to the string in text_font_draw_character.
  * fix for own recent error, [#24695] column_vector_multiplication call writes past end of array
  * was setting the vector array out of bounds with vec*=matrix, where the vector wasnt size 4.
  * bugfix [#24702] 3Dmanipulator does not display if view's layers are not synchronize to scene's layers.
  * bugfix [#24697] Trying to run bpy.ops.transform.create_orientation crashes Blender
  * bugfix [#24668] Deleting armature objects removes a user from its action, eventually leading to data loss
  * == filebrowser ==
  * * drawing code cleanup.
  * * list drawing code now uses uiStyleFontDraw like buttons etc.
  * * removed now unused function file_string_width_shortened.
  * * compile fix on non-Windows platforms.
  * [#24639] Snap to Face (retopo) doesn't work when clipping is enabled in mirror modifier.
  * bugfix [#24697]
  * Correct description for Projection property (it doesn't just work on vertice)
  * Seamless texture used for beveled curve is now really seamless (thanks to Mario G. Kishalmi aka lmg)
  * r33039 added dependency to COLLADA for blenderplayer, but it's really not needed there.
  * Stubbing for now.
  * netrender
  * unreported fixes for 3ds import
  * - non ASCII names would break loading.
  * - meshes with no faces would break loading too.
* Tue Nov  9 2010 davejplater@gmail.com
- Update to version 2.55.32968
- Some upstream changes :
  * Bugfix #20812 (and probably others)
  * Bug fix: cutting a sequencer movie strip with sound could crash in some cases.
  * Fix for [#24580] and [#24600]
  * Particles didn't want to stay cached, even if there were no actual chages.
  * Particle states weren't set properly for times before actual simulation start.
  * bugfix [#24403] Object.copy() duplicates armature action
  * bugfix [#24623] VSE strip animation data out of sync after moving using shift-s
  * bugfix [#24578] crash on browse directory w/ broken image file
  * [#24602] Netrender master node IP information is reset to [Default] no matter what
  * [#24601] Net rendering master node fails to send/retrieve files to/from slaves
  * bugfix [#22794] Inconsistent behaviour with Panorama, border rendering
  * fix for last commit with collada
  * bugfix [#24616] Apply Visual Transform doesn't always apply location
  * - object updates were not being flushed, so children weren't updating.
  * - apply the matrix relative to the parent, added this as an option to
    object_apply_mat4() which allows assigning the worldspace matrix in
    python without worrying about the parent.
  * Image editor & texture properties, add new Image, inits 'start' now
  to frame 1 for sequences.
  * Patch [#24608] Fix for typo and better indentation in command line help by Susanne H. (sanne). Thanks!
  * Fix for [#24597] Option External in Smoke cache affects settings of start and end frame of simulation
  * Don't change anything in the pointcache unless a valid external cache is found.
  * Second fix for [#24476] The driver is not displayed in GraphEditor.
  * Texture data still wasn't shown if material didn't have animation data.
  * Also unified the material/texture filtering logic a bit.
  * bugfix [#24583] Mesh.from_pydata does not properly construct faces
* Thu Nov  4 2010 davejplater@gmail.com
- Update to 3rd beta version 2.55.
- Removed blender wrapper as it's no longer necessary.
- Removed pre_checkin.sh - 3rd party blacklisted sources removed.
- Upstream changes:
  * Big improvements - This software has been used extensively in
  production of the Durian open movie project "Sintel".
  * Feature complete - Although some of the 2.5 targets have been
  postponed, such as multi-window support showing multiple scenes
  , a full RNA data level dependency graph, or radial menus.
  * Exciting improvements in Sculpting - Faster, much more stable
  and better brushes.
  * Missing/Incomplete Features - Although really most of it is
  there, not all functionality from 2.4x has been restored yet.
  Some functionality may work in a different way. Some features
  are still slower to use than before.
  * Bugs - We've fixed a lot lately, but there are still quite a
  few bugs. For this second beta around 200 bugs were fixed.
  * Changes - If you're used to the old Blenders, Blender 2.5 may
  seem quite different at first. Be prepared to read a bit about
  this, how to reconfigure things, and learn to use the new
  built-in 2.5 search functionality!
* Sat Jun 26 2010 davejplater@gmail.com
- Fixed bnc#615679 with build flags.
* Wed Jun 23 2010 davejplater@gmail.com
- Update to svn revision 29636 Removed blender-wrapper.patch
* Mon May 17 2010 davejplater@gmail.com
- Update to svn revision 28800 Removed blender-2.48-libtiff.patch
* Sat Jan 23 2010 davejplater@gmail.com
- Cleanup spec file, reinstate fdupes and add blender-2.49b-rpmlintrc
* Sat Dec 19 2009 jengelh@medozas.de
- enable parallel build
* Sat Oct 31 2009 davejplater@gmail.com
-Fixed x-blend.desktop errors and build flags
* Fri Oct 23 2009 davejplater@gmail.com
-Reincorporated pre_checkin.sh script
-Created blender-2.49b-undefined-opp.patch to fix undefined opperation
* Sat Oct 10 2009 crrodriguez@opensuse.org
- blender-2.48a-2.97: possible missing call to close [bnc#523443]
* Sat Sep 19 2009 dave.plater@yahoo.co.uk
- Removed kde3 dependency
* Thu Sep 17 2009 dave.plater@yahoo.co.uk
- Update to blender-2.49b
- Upstream bug fixes :- SoftBody, vertex groups were not notified on deletion & fixes for
  Mass and Spring Painting.
  Softbody, non mesh objects missing initializers [bug #18982].
  Self Shadow Vertex Colors, improved blur method to give more even results.
  Converting nurbs to a mesh ignored smoothing for Alt+C and from python.
  Object Active to Other, Fix python error when running in local view.
  Ancient resource leak where checkPackedFile would open a file and never close it.
  Fix for uninitialized memory use with X11 keyboard and tablet events.
  For more info see :-
  http://www.blender.org/development/release-logs/blender-249/249-update/
* Sat Sep  5 2009 dave.plater@yahoo.co.uk
- Changed blender-doc architecture to noarch
* Sat Aug 29 2009 dave.plater@yahoo.co.uk
- Moved BlenderQuickStart.pdf and blender.html from libdir to docdir
* Tue Aug 18 2009 dave.plater@yahoo.co.uk
- Update to blender-2.49a (bnc#525298)
- fixed uninitialized variables with help from Per Jessen blender-2.49-uninit-var.patch
- blender-doc is now in a seperate package
- New features in Blender-2.49a :-
  Blender player added again
  The Game Engine supports multiple streams of video textures
  for interactive playback in environments
  Real-time Dome rendering
  Game Engine speed-up
  Bullet Physics new features
  Game Engine Modifier support
  Improved Game Logic and Python API
  Texture Nodes
  Projection Painting
  Etch-a-ton armature sketching
  Boolean improvements
  JPEG2000 support
  Python Script extensions
  see http://www.blender.org/development/release-logs/blender-249/.
  for more details of new features in 2.49
* Mon Nov 10 2008 pnemec@suse.cz
- fix memory leak [bnc#442894]
  - new patch blender-2.48-memory_leak.patch
  - upstreamed under blender tracker 17974
* Wed Nov  5 2008 pnemec@suse.cz
- updated to 2.48 [bnc#441453]
  new features:
  - Real-time GLSL Materials
  - Grease Pencil
  - Game Logic
  - Bullet SoftBody
  - Game Engine notes
  - Colored shadows
  - Wind & Deflectors
  - remove upstreamed patches
    blender-2.42a-libtiff.patch
    blender-2.41-undefined_operation.patch
    blender-undefined-op.patch
  - added blender-2.48-uninitialized.patch to
    safe-initialization of pointers
  Fixed security problem [bnc#439121]
  - new patch pythonpath-2.48.patch
* Sun Sep 28 2008 ro@suse.de
- fix build: python version is 2.6
* Tue Sep  2 2008 pnemec@suse.cz
- updated to 2.47
  New tools and improvement have been made to the Snapping tools.
  Better Game Engine logic.
  Fixed an incorrect transformation for particle group visualization.
  Fixed negative value in the Gamma node with negative input.
  Tangent shading (which only affects specular) made bump mapping not work for diffuse.
  Fixed Mesh Deform Modifier not working on extruded curves.
  Fixed crash converting old particle system from a linked file.
  Object instancing didn't restore matrices correct for Environment Map,
  this could give object rendering in the wrong position.
  Compositor nodes with use nodes disabled didn't properly redraw the node window on changes.
- remove unneeded patches blender-python64.patch
  blender-2.41-uninitialized_variables.patch
  blender-2.42a-ffmpeg.patch
* Tue Aug 12 2008 pnemec@suse.cz
- remove doc package contents (now doc is in BuildService)
- repack source without problematic files in /extern direcotory
  [bnc#411821]
* Tue Jun 24 2008 pnemec@suse.cz
- updated to 2.46
  fixed [bnc#393489] (setting czech made blender SIGSEGV)
  remove ugly hack deleting incompatible files [bnc#333796]
  many new features (mouse wheel support, X-ray bones suppor ...
  see www.blender.org for complete list)
* Tue Apr 29 2008 pnemec@suse.cz
- fixed off-by-one problem in previous fix
* Fri Apr 18 2008 pnemec@suse.cz
- security fix (bnc#380922)
  new patch: buffer_overflow_380922-2.45.patch
* Fri Jan  4 2008 pnemec@suse.cz
- do not build againt key_internal.h mt19937int.c [#333796]
* Wed Oct  3 2007 coolo@suse.de
- update to 2.45 to fix compilation with gcc43
* Thu Jul  5 2007 coolo@suse.de
- put desktop file into package
* Tue Jun  5 2007 pnemec@suse.cz
- added script, which repack sources to remove uneeded files
* Tue May 29 2007 pnemec@suse.cz
- blenderplayer is no longer build
- fixing exutable flag on python scripts
- updated to 2.4.4
  - sculpt and multires
  - subsurface scattering
  - new composite nodes
  - character animation
* Thu May 24 2007 stbinner@suse.de
- remove X-SuSE-translate from .desktop file
* Thu Apr 12 2007 pnemec@suse.cz
- Repackaged to remove unused source [#262776]
  Binary unchanged.
* Wed Feb 21 2007 pnemec@suse.cz
- updated to 2.4.3
  added new feature: multi-resolution Meshes,
    multi-level UV, multi-layer images and multi-pass rendering,
    Mesh Sculpt and Retopo painting tools
* Mon Nov  6 2006 schwab@suse.de
- Use RPM_OPT_FLAGS.
- Fix bugs found through this.
- Fix linking of shared libraries.
* Tue Oct 24 2006 pnemec@suse.cz
- clean up spec file
  removed build-fix.patch needed for configuration
- added support for openal
* Mon Oct 23 2006 ro@suse.de
- added freealut-devel to buildrequires
* Fri Oct 20 2006 pnemec@suse.cz
- fix path`s in spec file. Plugins and help is now accesible from
  menu #[213228]
* Tue Oct 17 2006 pnemec@suse.cz
- removed ffmepg from requires
* Mon Oct 16 2006 pnemec@suse.cz
- updated to version 2.42 see Changelog for details
- large enhancement in package, whole specfile rewrited
  all patches either removed or rewrited
- new: support for quick time, better support for yafray
- new: package contains several blender scripts and plugins
* Tue Sep 19 2006 pnemec@suse.cz
- fixed amiguous variable evaluation
  (patch -undefined_operation.patch)
* Wed Sep 13 2006 ro@suse.de
- adde ftgl-devel to BuildRequires
* Thu Jun 29 2006 pnemec@suse.cz
- updated to version 2.41
- fixed some minor problems (uninitialized variables #188166)
  added patch uninitialized_variables.patch, missing_header.patch
- splited doc package, removed old documentation added new one #177578
* Sun Jan 29 2006 aj@suse.de
- Fix BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 pnemec@suse.cz
- Updated to version 2.40
- Scons patch moved from spec file to Scons.patch
* Tue Sep 20 2005 pnemec@suse.cz
- remove strict aliasing checking
* Tue Jul 26 2005 sbrabec@suse.cz
- Updated to version 2.37a.
* Wed May 18 2005 yxu@suse.de
- fixed serious compiler warnings
* Mon Apr 25 2005 yxu@suse.de
- Fixed for GCC4.
* Thu Jan  6 2005 sbrabec@suse.cz
- Updated to version 2.36.
* Fri Sep 17 2004 sbrabec@suse.cz
- Added yafray to requires.
- Search language setup, locale and font in /usr/share, not $HOME
  (#45201).
* Thu Sep  2 2004 sbrabec@suse.cz
- Updated to version 2.34.
* Fri Apr  9 2004 sbrabec@suse.cz
- Removed no longer needed LC_CTYPE work-around patch.
  http://projects.blender.org/tracker/?func=detail&atid=125&aid=490&group_id=9
* Sat Mar 13 2004 adrian@suse.de
- remove desktop file copy (use the template from KDE)
* Tue Feb 10 2004 ro@suse.de
- fixed patchfile for lib64 patch
* Fri Feb  6 2004 sbrabec@suse.cz
- Updated to version 2.32.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Tue Oct  7 2003 ro@suse.de
- use SDL-devel-packages in neededforbuild
* Thu Sep 18 2003 meissner@suse.de
- correct lib64 fix, do not modify buildroot.
* Wed Sep 17 2003 adrian@suse.de
- add menu entry
* Thu Sep 11 2003 sbrabec@suse.cz
- Crash on startup LC_CTYPE work-around (bug #30166, Blender bug #490).
* Thu Sep 11 2003 sbrabec@suse.cz
- Crash on startup fix with Python 2.3 from CVS (bug #30166).
* Thu Aug 21 2003 sbrabec@suse.cz
- Updated to version 2.28a.
* Wed Aug  6 2003 sbrabec@suse.cz
- Updated to version 2.28.
* Thu Jun 12 2003 ro@suse.de
- added directory to filelist
* Tue May 27 2003 ro@suse.de
- remove unpackaged files from buildroot
* Wed May  7 2003 ro@suse.de
- build on python-2.3
* Mon Mar 31 2003 ro@suse.de
- use mesa-devel-packages in neededforbuild
* Wed Feb 19 2003 sndirsch@suse.de
- fixed blendercreator-sample (blendercreator no longer exists;
  it's now called blender)
- therefore renamed blendercreator-sample to blender-sample
- adjusted SuSE menu entries in PDB
* Mon Feb 17 2003 sbrabec@suse.cz
- Updated to version 2.26.
- Workaround of linker segfault.
* Fri Jan 17 2003 sbrabec@suse.cz
- Fixed permissions of blendercreator-sample.
* Wed Jan 15 2003 ro@suse.de
- fix for libpng (needs -lm -lz)
- run autogen.sh
* Wed Jan 15 2003 sbrabec@suse.cz
- Added blendercreator-sample binary and usefull links.
* Tue Jan 14 2003 sbrabec@suse.cz
- Added sample geeko.blend.
- Moved documentation to subdir PublisherDoc.
- Removed blendermodule.
* Tue Nov 26 2002 sbrabec@suse.cz
- Workaround biarch bugs in python.m4 (bug 22011) and libtool search
  paths (bug 22010).
* Wed Nov 20 2002 sbrabec@suse.cz
- Added official Blender documentation.
* Tue Nov  5 2002 sbrabec@suse.cz
- Added first public GPL release with unofficial automake support.
